@@ -933,7 +933,7 @@ int entitycmpfnc( const entity_t *a, const entity_t *b )
 }
 
 /**
- * \brief  Rendering performance test.
+ * @brief  Rendering performance test.
  *
  * Target of 'timerefresh' command. When invoked with an argument, end of
  * frame flush and page flipping are not done. Modified 2011-02 with
@@ -1881,6 +1881,8 @@ void SCR_UpdateScreen (void)
 			// do 3D refresh drawing, and then update the screen
 			SCR_CalcVrect ();
 
+			need_free_vbo = true;
+
 			V_RenderView ( separation[i] );
 
 			SCR_DrawStats ();
@@ -1903,6 +1905,9 @@ void SCR_UpdateScreen (void)
 
 			SCR_DrawConsole ();
 
+			if (need_free_vbo)		
+				R_VCFreeFrame();
+
 			M_Draw ();
 
 			SCR_DrawLoading ();
