@@ -31,6 +31,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 //
 int			gun_frame;
 struct model_s	*gun_model;
+//=============
 
 int r_numflares;
 flare_t r_flares[MAX_FLARES];
@@ -41,7 +42,6 @@ grass_t r_grasses[MAX_GRASSES];
 int r_numbeams;
 beam_t	r_beams[MAX_BEAMS];
 
-//=============
 extern cvar_t *cl_showPlayerNames;
 extern cvar_t *name;
 extern char map_music[128];
@@ -57,6 +57,7 @@ cvar_t		*cl_testblend;
 
 cvar_t		*cl_stats;
 
+qboolean need_free_vbo;
 
 int			r_numdlights;
 dlight_t	r_dlights[MAX_DLIGHTS];
@@ -878,7 +879,7 @@ void V_RenderView( float stereo_separation )
 			r_numdlights = 0;
 		if (!cl_add_blend->value)
 		{
-			VectorClear (cl.refdef.blend);
+			Vector4Clear (cl.refdef.blend);
 		}
 
 		cl.refdef.num_entities = r_numentities;
@@ -907,6 +908,9 @@ void V_RenderView( float stereo_separation )
 
 	cl.refdef.rdflags |= RDF_BLOOM;   //BLOOMS
 
+	R_VCFreeFrame();
+	need_free_vbo = false;
+
 	R_RenderFrame (&cl.refdef);
 	if (cl_stats->value)
 		Com_Printf ("ent:%i  lt:%i  part:%i\n", r_numentities, r_numdlights, r_numparticles);
@@ -928,7 +932,7 @@ void V_RenderView( float stereo_separation )
 }
 
 /**
- * \brief Console output of position and orientation
+ * @brief Console output of position and orientation
  *
  * Target of 'viewpos' command. Modified 2011-02. Added pitch.
  * Helps with repeatable positioning for timerefresh command
