@@ -254,6 +254,7 @@ extern client_static_t	cls;
 //
 extern	cvar_t	*cl_stereo_separation;
 extern	cvar_t	*cl_stereo;
+extern	cvar_t	*cl_maxfps;
 
 extern	cvar_t	*cl_gun;
 extern	cvar_t	*cl_add_blend;
@@ -267,6 +268,7 @@ extern	cvar_t	*cl_autoskins;
 extern  cvar_t	*cl_healthaura;
 extern  cvar_t	*cl_noblood;
 extern  cvar_t	*cl_disbeamclr;
+extern  cvar_t	*cl_dmlights;
 extern  cvar_t	*cl_brass;
 extern  cvar_t	*cl_playtaunts;
 extern	cvar_t	*cl_centerprint;
@@ -297,6 +299,7 @@ extern	cvar_t	*sensitivity;
 extern  cvar_t  *menu_sensitivity;
 
 extern	cvar_t	*m_smoothing;
+extern	cvar_t	*m_filter;
 extern	cvar_t	*m_pitch;
 extern	cvar_t	*m_yaw;
 extern	cvar_t	*m_forward;
@@ -321,6 +324,8 @@ extern	cvar_t	*cl_IRC_nickname;
 extern	cvar_t	*cl_IRC_kick_rejoin;
 extern	cvar_t	*cl_IRC_reconnect_delay;
 
+extern	cvar_t	*cl_latest_game_version;
+
 typedef struct
 {
 	int		key;				// so entities can reuse same entry
@@ -528,6 +533,11 @@ void IN_CenterView (void);
 float CL_KeyState (kbutton_t *key);
 char *Key_KeynumToString (int keynum);
 
+extern qboolean mouse_available;
+
+void IN_MLookDown (void);
+void IN_MLookUp (void);
+
 //cl_irc.c
 void CL_IRCSetup(void);
 void CL_InitIRC(void);
@@ -572,9 +582,31 @@ typedef struct _PLAYERSTATS {
 	int ranking;
 } PLAYERSTATS;
 
-void getStatsDB( void );
+typedef struct _STATSLOGINSTATE {
+	int requestType;
+	qboolean validated;
+	qboolean hashed;
+	char old_password[256];
+} LOGINSTATE;
+
+#define STATSLOGIN 1
+#define STATSPWCHANGE 2
+
+void STATS_getStatsDB( void );
+void STATS_RequestVerification( void );
+void STATS_RequestPwChange (void);
+void STATS_AuthenticateStats (char *vstring);
+void STATS_ChangePassword (char *vstring);
+void STATS_Logout (void);
 PLAYERSTATS getPlayerRanking ( PLAYERSTATS player );
 PLAYERSTATS getPlayerByRank ( int rank, PLAYERSTATS player );
+LOGINSTATE currLoginState;
+
+//
+// cl_updates.c
+//
+
+void getLatestGameVersion( void );
 
 //
 // cl_view.c
@@ -582,6 +614,7 @@ PLAYERSTATS getPlayerByRank ( int rank, PLAYERSTATS player );
 
 #define CL_LOADMSG_LENGTH 96
 
+extern qboolean need_free_vbo;
 qboolean loadingMessage;
 char loadingMessages[5][2][CL_LOADMSG_LENGTH];
 float loadingPercent;
@@ -654,6 +687,7 @@ void CL_DiminishingTrail (vec3_t start, vec3_t end, centity_t *old, int flags);
 void CL_BfgParticles (entity_t *ent);
 void CL_AddParticles (void);
 void CL_EntityEvent (entity_state_t *ent);
+qboolean server_is_team; //used for player visibility light code
 
 //
 // menus
