@@ -102,11 +102,54 @@ typedef struct
 
 #define RDF_BLOOM         4      //BLOOMS
 
+#define	MAX_VERTEX_CACHES	4096
 #define MAX_VBO_XYZs		65536
 
-vec3_t	vbo_shadow[MAX_VBO_XYZs];
-vec3_t	vbo_shadow2[MAX_VBO_XYZs];
-vec3_t	vbo_shadow3[MAX_VBO_XYZs];
+typedef enum {
+	VBO_STATIC,
+	VBO_DYNAMIC
+} vertCacheMode_t;
+
+typedef enum {
+	VBO_STORE_ANY,
+	VBO_STORE_XYZ,
+	VBO_STORE_INDICES,
+	VBO_STORE_ST,
+	VBO_STORE_SHADOWXYZ,
+	VBO_STORE_SHADOWINDICES,
+	VBO_STORE_NORMAL,
+	VBO_STORE_BINORMAL,
+	VBO_STORE_TANGENT
+} vertStoreMode_t;
+
+typedef struct vertCache_s
+{
+	struct vertCache_s	*prev;
+	struct vertCache_s	*next;
+
+	vertCacheMode_t		mode;
+
+	int					size;
+
+	void				*pointer;
+
+	vec3_t				position;
+
+	vertStoreMode_t		store;
+	struct model_s		*mod;
+#ifdef SHADOWVBO
+	struct entity_s		*ent;
+#endif
+	unsigned			id;
+} vertCache_t;
+
+typedef struct {
+	vertCache_t		*freeVertCache;
+	vertCache_t		activeVertCache;
+	vertCache_t		vertCacheList[MAX_VERTEX_CACHES];
+} vertCacheManager_t;
+
+vertCacheManager_t	vcm;
 
 typedef struct entity_s
 {
@@ -363,4 +406,9 @@ typedef struct RadarEnt_s{
 extern int numRadarEnts;
 extern RadarEnt_t RadarEnts[MAX_RADAR_ENTS];
 
+extern cursor_t cursor;
+
+
+qboolean is_localhost; //because ref_gl can't access cls.servername.
+
 #endif // __REF_H
