@@ -118,13 +118,18 @@ void ACEAI_Think (edict_t *self)
 	{
 		self->client->buttons = 0;
 		ucmd.buttons = BUTTON_ATTACK;
+		/*
+		 * do nothing else until respawned.
+		 */
+		ClientThink (self, &ucmd);
+		self->nextthink = level.time + FRAMETIME;
+		return;
 	}
 
 	if(self->state == STATE_WANDER && self->wander_timeout < level.time)
 	  ACEAI_PickLongRangeGoal(self); // pick a new long range goal
 
 	// Kill the bot if completely stuck somewhere
-
 	if(VectorLength(self->velocity) > 37)
 		self->suicide_timeout = level.time + 10.0;
 
@@ -132,6 +137,8 @@ void ACEAI_Think (edict_t *self)
 	{
 		self->health = 0;
 		player_die (self, self, self, 100000, vec3_origin);
+		// bot suicide, branch around irrelevant stuff.
+		goto clientthink;
 	}
 
 	//reset the state from pauses for taunting
@@ -143,35 +150,39 @@ void ACEAI_Think (edict_t *self)
 		self->client->spawnprotected = false;
 
 	// Find any short range goal - but not if in air(ie, jumping a jumppad)
-	if(self->groundentity)
+	if (self->groundentity)
 		ACEAI_PickShortRangeGoal(self);
 
 	// Look for enemies
-	if(ACEAI_FindEnemy(self))
+	if ( ACEAI_FindEnemy( self ) )
 	{
-		ACEAI_ChooseWeapon(self);
-		ACEMV_Attack (self, &ucmd);
+		ACEAI_ChooseWeapon( self );
+		ACEMV_Attack( self, &ucmd );
 	}
 	else
 	{
 		// Execute the move, or wander
-		if(self->state == STATE_WANDER)
-			ACEMV_Wander(self,&ucmd);
-		else if(self->state == STATE_MOVE)
-			ACEMV_Move(self,&ucmd);
+		ACEAI_ChooseWeapon( self ); // for deselecting violator
+		if ( self->state == STATE_WANDER )
+		{
+			ACEMV_Wander( self, &ucmd );
+		}
+		else if ( self->state == STATE_MOVE )
+		{
+			ACEMV_Move( self, &ucmd );
+		}
+
 	}
 
-	//debug_printf("State: %d\n",self->state);
-
-	// set approximate ping
-	ucmd.msec = 75 + floor (random () * 25) + 1;
-
+clientthink:
+	// debug_printf("State: %d\n",self->state);
+	ucmd.msec = 100; // bots "client loop" runs at server frame rate
 	self->client->ping = 0; //show in scoreboard ping of 0
 
 	// set bot's view angle
-	ucmd.angles[PITCH] = ANGLE2SHORT(self->s.angles[PITCH]);
-	ucmd.angles[YAW] = ANGLE2SHORT(self->s.angles[YAW]);
-	ucmd.angles[ROLL] = ANGLE2SHORT(self->s.angles[ROLL]);
+	ucmd.angles[PITCH] = ANGLE2SHORT( self->s.angles[PITCH] );
+	ucmd.angles[YAW] = ANGLE2SHORT( self->s.angles[YAW] );
+	ucmd.angles[ROLL] = ANGLE2SHORT( self->s.angles[ROLL] );
 
 	// send command through id's code
 	ClientThink (self, &ucmd);
@@ -186,90 +197,125 @@ void ACEAI_Think (edict_t *self)
 ///////////////////////////////////////////////////////////////////////
 void ACEAI_PickLongRangeGoal(edict_t *self)
 {
-
 	int i;
 	int node;
 	float weight,best_weight=0.0;
 	int current_node,goal_node=0;
 	edict_t *goal_ent=NULL, *ent;
 	float cost;
+#ifdef CTFNODES
+	gitem_t *flag1_item, *flag2_item;
+	qboolean hasFlag = false;
 
 	// look for a target
-	current_node = ACEND_FindClosestReachableNode(self,NODE_DENSITY,NODE_ALL);
+
+	//if flag in possession, try to find base nodes
+	if(ctf->value)
+	{
+		flag1_item = FindItemByClassname("item_flag_red");
+		flag2_item = FindItemByClassname("item_flag_blue");
+
+		if (self->client->pers.inventory[ITEM_INDEX(flag1_item)])
+		{
+			current_node = ACEND_FindClosestReachableNode(self,NODE_DENSITY,NODE_BLUEBASE);
+			hasFlag = true;
+		}
+		else if (self->client->pers.inventory[ITEM_INDEX(flag2_item)])
+		{
+			current_node = ACEND_FindClosestReachableNode(self,NODE_DENSITY,NODE_REDBASE);
+			hasFlag = true;
+		}
+		else
+			current_node = ACEND_FindClosestReachableNode(self,NODE_DENSITY,NODE_ALL);
+	}
+	else
+#endif
+		current_node = ACEND_FindClosestReachableNode(self,NODE_DENSITY,NODE_ALL);
 
 	self->current_node = current_node;
 
 	if(current_node == -1)
-	{
+	{		
 		self->state = STATE_WANDER;
 		self->wander_timeout = level.time + 1.0;
 		self->goal_node = -1;
 		return;
 	}
-
-	///////////////////////////////////////////////////////
-	// Items
-	///////////////////////////////////////////////////////
-	for(i=0;i<num_items;i++)
+#ifdef CTFNODES
+	if(!hasFlag)
 	{
-		if(item_table[i].ent == NULL || item_table[i].ent->solid == SOLID_NOT) // ignore items that are not there.
-			continue;
-
-		cost = ACEND_FindCost(current_node,item_table[i].node);
-
-		if(cost == INVALID || cost < 2) // ignore invalid and very short hops
-			continue;
-
-		weight = ACEIT_ItemNeed(self, item_table[i].item);
-
-		weight *= random(); // Allow random variations
-		weight /= cost; // Check against cost of getting there
-
-		if(weight > best_weight)
+#endif
+		///////////////////////////////////////////////////////
+		// Items
+		///////////////////////////////////////////////////////
+		for(i=0;i<num_items;i++)
 		{
-			best_weight = weight;
-			goal_node = item_table[i].node;
-			goal_ent = item_table[i].ent;
-		}
-	}
+			if(item_table[i].ent == NULL || item_table[i].ent->solid == SOLID_NOT) // ignore items that are not there.
+				continue;
 
-	///////////////////////////////////////////////////////
-	// Players
-	///////////////////////////////////////////////////////
-	// This should be its own function and is for now just
-	// finds a player to set as the goal.
-	for(i=0;i<game.maxclients;i++)
+			cost = ACEND_FindCost(current_node,item_table[i].node);
+
+			if(cost == INVALID || cost < 2) // ignore invalid and very short hops
+				continue;
+
+			weight = ACEIT_ItemNeed(self, item_table[i].item);
+
+			weight *= random(); // Allow random variations
+			weight /= cost; // Check against cost of getting there
+
+			if(weight > best_weight)
+			{
+				best_weight = weight;
+				goal_node = item_table[i].node;
+				goal_ent = item_table[i].ent;
+			}
+		}
+
+		///////////////////////////////////////////////////////
+		// Players
+		///////////////////////////////////////////////////////
+		// This should be its own function and is for now just
+		// finds a player to set as the goal.
+		for(i=0;i<game.maxclients;i++)
+		{
+			ent = g_edicts + i + 1;
+			if(ent == self || !ent->inuse || (ent->client->invis_framenum > level.framenum))
+				continue;
+
+			node = ACEND_FindClosestReachableNode(ent,NODE_DENSITY,NODE_ALL);
+			cost = ACEND_FindCost(current_node, node);
+
+			if(cost == INVALID || cost < 3) // ignore invalid and very short hops
+				continue;
+
+			weight = 0.3;
+
+			weight *= random(); // Allow random variations
+			weight /= cost; // Check against cost of getting there
+
+			//to do - check for flag, and if enemy has the flag, up the weight.
+			if(weight > best_weight)
+			{
+				best_weight = weight;
+				goal_node = node;
+				goal_ent = ent;
+			}
+		}
+#ifdef CTFNODES
+	}
+	else
 	{
-		ent = g_edicts + i + 1;
-		if(ent == self || !ent->inuse || (ent->client->invis_framenum > level.framenum))
-			continue;
-
-		node = ACEND_FindClosestReachableNode(ent,NODE_DENSITY,NODE_ALL);
-		cost = ACEND_FindCost(current_node, node);
-
-		if(cost == INVALID || cost < 3) // ignore invalid and very short hops
-			continue;
-
-		weight = 0.3;
-
-		weight *= random(); // Allow random variations
-		weight /= cost; // Check against cost of getting there
-
-		//check for flag, and if enemy has the flag, up the weight.
-		if(weight > best_weight)
-		{
-			best_weight = weight;
-			goal_node = node;
-			goal_ent = ent;
-		}
+		goal_node = current_node;
+		best_weight = 1.0;
 	}
-
+#endif
 	// If do not find a goal, go wandering....
 	if(best_weight == 0.0 || goal_node == INVALID)
-	{
+	{			
 		self->goal_node = INVALID;
 		self->state = STATE_WANDER;
 		self->wander_timeout = level.time + 1.0;
+
 		if(debug_mode)
 			debug_printf("%s did not find a LR goal, wandering.\n",self->client->pers.netname);
 		return; // no path?
@@ -280,7 +326,9 @@ void ACEAI_PickLongRangeGoal(edict_t *self)
 	self->tries = 0; // Reset the count of how many times we tried this goal
 
 	if(goal_ent != NULL && debug_mode)
-		debug_printf("%s selected a %s at node %d for LR goal.\n",self->client->pers.netname, goal_ent->classname, goal_node);
+		debug_printf("%s selected a %s at node %d (type: %i) for LR goal.\n",self->client->pers.netname, goal_ent->classname, goal_node, nodes[goal_node].type);
+	else if(debug_mode)
+		debug_printf("%s selected node %d (type: %i) for LR goal.\n",self->client->pers.netname, goal_node, nodes[goal_node].type);
 
 	ACEND_SetGoal(self,goal_node);
 
@@ -318,9 +366,9 @@ void ACEAI_PickShortRangeGoal(edict_t *self)
 	float weight,best_weight=0.0;
 	edict_t *best = NULL;
 	int index;
-
+			
 	// look for a target (should make more efficent later)
-	target = findradius(NULL, self->s.origin, 200);//was 200
+	target = findradius(NULL, self->s.origin, 200);
 
 	while(target)
 	{
@@ -405,6 +453,7 @@ qboolean ACEAI_infront (edict_t *self, edict_t *other)
 
 	if (dot > (1.0 - self->awareness))
 		return true;
+
 	return false;
 }
 
@@ -483,9 +532,13 @@ qboolean ACEAI_FindEnemy(edict_t *self)
 
 	if(self->oldenemy != NULL) //(was shot from behind)
 	{
-		self->enemy = self->oldenemy;
-		self->oldenemy = NULL;
-		return true;
+		if(!OnSameTeam(self, self->oldenemy))
+		{
+			//to do - add code to ask for help if carrying the flag
+			self->enemy = self->oldenemy;
+			self->oldenemy = NULL;
+			return true;
+		}
 	}
 
 	for(i=0;i<game.maxclients;i++)
@@ -501,6 +554,8 @@ qboolean ACEAI_FindEnemy(edict_t *self)
 			VectorSubtract(self->s.origin, ent->s.origin, dist);
 			weight = VectorLength( dist );
 
+			//add some more checks here, for health and armor, just slight, but enough to make them favor going for the weaker player
+
 			// Check if best target, or better than current target
 			if (weight < bestweight)
 			{
@@ -539,10 +594,12 @@ qboolean ACEAI_CheckShot(edict_t *self)
 {
 	trace_t tr;
 
+	assert( self->enemy != NULL );
+
 	tr = gi.trace (self->s.origin, tv(-8,-8,-8), tv(8,8,8), self->enemy->s.origin, self, MASK_SOLID);
 
 	// Blocked, do not shoot
-	if (tr.fraction != 1.0)
+	if ( tr.fraction < 1.0f )
 		return false;
 
 	return true;
@@ -627,21 +684,45 @@ void ACEAI_Use_Sproing (edict_t *ent)
 ///////////////////////////////////////////////////////////////////////
 // Choose the best weapon for bot
 ///////////////////////////////////////////////////////////////////////
+
+/*
+
+1 : 1.0 //blaster accuracy
+2 : 1.0 //alien disruptor accuracy
+3 : 1.0 //pulse rifle accuracy
+4 : 1.0 //flame thrower accuracy
+5 : 1.0 //homing rocket launcher accuracy
+6 : 1.0 //rocket launcher accuracy
+7 : 1.0 //alien smartgun accuracy
+8 : 1.0 //alien beamgun accuracy
+9 : 1.0 //alien vaporizer accuracy
+
+ */
+#define ACCURACY_BLASTER         1
+#define ACCURACY_DISRUPTOR       2
+#define ACCURACY_CHAINGUN        3
+#define ACCURACY_FLAMETHROWER    4
+#define ACCURACY_NOTUSED         5
+#define ACCURACY_ROCKETLAUNCHER  6
+#define ACCURACY_SMARTGUN        7
+#define ACCURACY_BEAMGUN         8
+#define ACCURACY_VAPORIZER       9
+
 void ACEAI_ChooseWeapon(edict_t *self)
 {
 	float range;
 	vec3_t v;
 	float c;
+	qboolean selected;
+	qboolean clear_shot;
 
-	if (self->in_vehicle) {
+	if (self->in_vehicle || self->in_deathball)
+	{
 		return;
 	}
 
-	if (self->in_deathball) {
-		return; //cannot switch or fire weapons when in a deathball.
-	}
-
-	if(self->client->resp.powered) { //got enough reward points, use something
+	if(self->client->resp.powered)
+	{ //got enough reward points, use something
 		c = random();
 		if( c < 0.5)
 			ACEAI_Use_Invisibility(self);
@@ -651,160 +732,228 @@ void ACEAI_ChooseWeapon(edict_t *self)
 			ACEAI_Use_Sproing(self);
 	}
 
+	// calculate distance to enemy target for range-based weapon selection
+	clear_shot = true;
+	if ( self->enemy != NULL )
+	{
+		VectorSubtract( self->s.origin, self->enemy->s.origin, v );
+		range = VectorLength( v );
+		clear_shot = ACEAI_CheckShot( self );
+	}
+	else if ( self->client->pers.weapon->weapmodel == WEAP_VIOLATOR )
+	{
+		// put away the violator, and select something else
+		//  using a fake range.
+		range = 500.0F;
+	}
+	else
+	{ // otherwise, keep current weapon when there is no target.
+		return;
+	}
+
 	//mutators
-	if(instagib->value || rocket_arena->value)
+	/*
+	 * Unconditionally choose for insta and rockets.
+	 */
+	if ( instagib->integer )
+	{
+		// TODO: consider whether this prevents using violator
+		//       and whether or not that is a good thing.
+		if ( self->client->pers.weapon->weapmodel != WEAP_DISRUPTOR )
+		{
+			self->client->newweapon = FindItem( "Alien Disruptor" );
+			assert( self->client->newweapon != NULL );
+			ChangeWeapon( self );
+		}
+		self->accuracy = self->weapacc[ACCURACY_DISRUPTOR];
 		return;
+	}
 
-	// if no enemy, then what are we doing here?
-	if(!self->enemy)
+	if ( rocket_arena->integer )
+	{
+		if ( self->client->pers.weapon->weapmodel != WEAP_ROCKETLAUNCHER )
+		{
+			self->client->newweapon = FindItem( "Rocket Launcher" );
+			assert( self->client->newweapon != NULL );
+			ChangeWeapon( self );
+		}
+		self->accuracy = self->weapacc[ACCURACY_ROCKETLAUNCHER];
 		return;
+	}
 
-	// Base selection on distance.
-	VectorSubtract (self->s.origin, self->enemy->s.origin, v);
-	range = VectorLength(v);
-
-	//what is the bot's favorite weapon? The bot will always check for it's favorite
-	//weapon first, which is set in the bot's config file.
-
-	if(!strcmp(self->faveweap, "Alien Vaporizer") && self->skill > 1)
+	// insta/rockets hybrid
+	if ( insta_rockets->integer  )
 	{
-		if(ACEIT_ChangeWeapon(self,FindItem(self->faveweap)))
+		if ( self->skill > 0 && range < 170.0F ) // Little closer than usual (normally 200)
 		{
-			self->accuracy = self->weapacc[9];
-			return;
-		}
-	}
-	if(!strcmp(self->faveweap, "Alien Disruptor"))
-	{
-		if(ACEIT_ChangeWeapon(self,FindItem(self->faveweap)))
-		{
-			self->accuracy = self->weapacc[2];
-			return;
-		}
-	}
-	if(!strcmp(self->faveweap, "Disruptor"))
-	{
-		if(ACEIT_ChangeWeapon(self,FindItem(self->faveweap)))
-		{
-			self->accuracy = self->weapacc[8];
-			return;
-		}
-	}
-    if(!strcmp(self->faveweap, "Pulse Rifle"))
-	{
-		if(ACEIT_ChangeWeapon(self,FindItem(self->faveweap)))
-		{
-			self->accuracy = self->weapacc[3];
-			return;
-		}
-	}
-	if(!strcmp(self->faveweap, "Alien Smartgun"))
-	{
-		if(ACEAI_CheckShot(self) && ACEIT_ChangeWeapon(self, FindItem("Alien Smartgun")))
-		{
-			self->accuracy = self->weapacc[7];
-			return;
-		}
-	}
-	if(!strcmp(self->faveweap, "Rocket Launcher"))
-	{
-		if(range > 200)
-		{
-			if(ACEAI_CheckShot(self) && ACEIT_ChangeWeapon(self,FindItem("Rocket Launcher")))
+			if ( self->client->pers.weapon->weapmodel != WEAP_VIOLATOR )
 			{
-				self->accuracy = self->weapacc[6];
+				self->client->newweapon = FindItem( "Violator" );
+				assert( self->client->newweapon != NULL );
+				ChangeWeapon( self );
+			}
+			self->accuracy = 1.0;
+			return;
+		}
+		if ( clear_shot && range > 169.0F && range < 450.0F ) // Medium Range, use Rockets
+		{
+			if ( self->client->pers.weapon->weapmodel != WEAP_ROCKETLAUNCHER )
+			{
+				self->client->newweapon = FindItem( "Rocket Launcher" );
+				assert( self->client->newweapon != NULL );
+				ChangeWeapon( self );
+			}
+			self->accuracy = self->weapacc[ACCURACY_ROCKETLAUNCHER];
+			return;
+		}
+		// Long range (or possibly short range for skill 0 bots)
+		if ( self->client->pers.weapon->weapmodel != WEAP_DISRUPTOR )
+		{
+			self->client->newweapon = FindItem( "Alien Disruptor" );
+			assert( self->client->newweapon != NULL );
+			ChangeWeapon( self );
+		}
+		self->accuracy = self->weapacc[ACCURACY_DISRUPTOR];
+		return;
+	}
+
+	// what is the bot's favorite weapon?
+	// The bot will always check for it's favorite weapon first,
+	// which is set in the bot's config file.
+	if ( !strcmp( self->faveweap, "Alien Vaporizer" ) && self->skill > 1 )
+	{
+		if ( ACEIT_ChangeWeapon( self, FindItem( self->faveweap ) ) )
+		{
+			self->accuracy = self->weapacc[ACCURACY_VAPORIZER];
+			return;
+		}
+	}
+	if ( !strcmp( self->faveweap, "Alien Disruptor" ) )
+	{
+		if ( ACEIT_ChangeWeapon( self, FindItem( self->faveweap ) ) )
+		{
+			self->accuracy = self->weapacc[ACCURACY_DISRUPTOR];
+			return;
+		}
+	}
+	if ( !strcmp( self->faveweap, "Disruptor" ) )
+	{
+		if ( ACEIT_ChangeWeapon( self, FindItem( self->faveweap ) ) )
+		{
+			self->accuracy = self->weapacc[ACCURACY_BEAMGUN];
+			return;
+		}
+	}
+    if ( !strcmp( self->faveweap, "Pulse Rifle" ) )
+	{
+		if ( ACEIT_ChangeWeapon( self, FindItem( self->faveweap ) ) )
+		{
+			self->accuracy = self->weapacc[ACCURACY_CHAINGUN];
+			return;
+		}
+	}
+	if ( !strcmp( self->faveweap, "Alien Smartgun" ) )
+	{
+		if ( clear_shot && ACEIT_ChangeWeapon( self, FindItem( "Alien Smartgun" )))
+		{
+			self->accuracy = self->weapacc[ACCURACY_SMARTGUN];
+			return;
+		}
+	}
+	if ( !strcmp( self->faveweap, "Rocket Launcher" ) )
+	{
+		if ( range > 200.0f )
+		{
+			if ( clear_shot && ACEIT_ChangeWeapon( self, FindItem( "Rocket Launcher" )))
+			{
+				self->accuracy = self->weapacc[ACCURACY_ROCKETLAUNCHER];
 				return;
 			}
 		}
 	}
-	if(!strcmp(self->faveweap, "Flame Thrower"))
+	if ( !strcmp( self->faveweap, "Flame Thrower" ) )
 	{
-		if(range < 500 || (range < 800 && self->skill == 3)) {
-				if(ACEIT_ChangeWeapon(self,FindItem("Flame Thrower")))
-				{
-					self->accuracy = self->weapacc[4];
-					return;
-				}
-		}
-	}
-	if(!strcmp(self->faveweap, "Violator") && self->skill > 0)
-	{
-		if(range < 300) { //because it's a fav weap, we want them to really try and use it
-				if(ACEIT_ChangeWeapon(self,FindItem("Violator")))
-				{
-					self->accuracy = 1.0;
-					return;
-				}
-		}
-	}
-	//now go through normal weapon favoring routine
-	// always favor the Vaporizor, unless close, then use the violator
-	if(range < 200 && self->skill > 0) {
-		if(ACEIT_ChangeWeapon(self,FindItem("Violator")))
+		if ( range < 500.0f || (range < 800.0f && self->skill == 3) )
 		{
-			self->accuracy = 1.0;
-			return;
+			if ( ACEIT_ChangeWeapon( self, FindItem( "Flame Thrower" ) ) )
+			{
+				self->accuracy = self->weapacc[ACCURACY_FLAMETHROWER];
+				return;
+			}
+		}
+	}
+	if ( !strcmp( self->faveweap, "Violator" ) && self->skill > 0 )
+	{
+		if ( range < 300.0f )
+		{ //because it's a fav weap, we want them to really try and use it
+			if ( ACEIT_ChangeWeapon( self, FindItem( "Violator" ) ) )
+			{
+				self->accuracy = 1.0;
+				return;
+			}
 		}
 	}
 
-	if(self->skill > 1) {
-		if(ACEIT_ChangeWeapon(self,FindItem("Alien Vaporizer")))
+	// now go through normal weapon favoring routine
+	//  always favor the Vaporizor, unless close, then use the violator
+	if ( range < 200.0f && self->skill > 0 )
+	{
+		selected = ACEIT_ChangeWeapon( self, FindItem( "Violator" ));
+		assert( selected );
+		self->accuracy = 1.0f;
+		return;
+	}
+	if ( self->skill > 1 )
+	{
+		if ( ACEIT_ChangeWeapon( self, FindItem( "Alien Vaporizer" )))
 		{
-			self->accuracy = self->weapacc[9];
+			self->accuracy = self->weapacc[ACCURACY_VAPORIZER];
 			return;
 		}
 	}
-
-	if(ACEAI_CheckShot(self) && ACEIT_ChangeWeapon(self, FindItem("Alien Smartgun")))
+	if ( clear_shot && ACEIT_ChangeWeapon( self, FindItem( "Alien Smartgun" )))
 	{
-		self->accuracy = self->weapacc[7];
+		self->accuracy = self->weapacc[ACCURACY_SMARTGUN];
 		return;
 	}
 
 	// Longer range so the bot doesn't blow himself up!
-	if(range > 200)
+	if ( clear_shot && range > 200.0f )
 	{
-		if(ACEAI_CheckShot(self) && ACEIT_ChangeWeapon(self,FindItem("Rocket Launcher")))
+		if ( ACEIT_ChangeWeapon( self, FindItem( "Rocket Launcher" )))
 		{
-			self->accuracy = self->weapacc[6];
+			self->accuracy = self->weapacc[ACCURACY_ROCKETLAUNCHER];
 			return;
 		}
 	}
 
 	// Only use FT in certain ranges
-	if(range < 500 || (range < 800 && self->skill == 3)) {
-
-			if(ACEIT_ChangeWeapon(self,FindItem("Flame Thrower")))
-			{
-				self->accuracy = self->weapacc[4];
-				return;
-			}
-	}
-
-	if(ACEIT_ChangeWeapon(self,FindItem("Disruptor")))
+	if ( range < 500.0f || (range < 800.0f && self->skill == 3) )
 	{
-		self->accuracy = self->weapacc[8];
-		return;
+		if ( ACEIT_ChangeWeapon( self, FindItem( "Flame Thrower" ) ))
+		{
+			self->accuracy = self->weapacc[ACCURACY_FLAMETHROWER];
+			return;
+		}
 	}
-
-	if(ACEIT_ChangeWeapon(self,FindItem("Pulse Rifle")))
+	if ( ACEIT_ChangeWeapon( self, FindItem( "Disruptor" ) ))
 	{
-		self->accuracy = self->weapacc[3];
+		self->accuracy = self->weapacc[ACCURACY_BEAMGUN];
 		return;
 	}
-
-	if(ACEIT_ChangeWeapon(self,FindItem("Alien Disruptor")))
+	if ( ACEIT_ChangeWeapon( self, FindItem( "Pulse Rifle" ) ))
 	{
-		self->accuracy = self->weapacc[2];
+		self->accuracy = self->weapacc[ACCURACY_CHAINGUN];
+		return;
+	}
+	if ( ACEIT_ChangeWeapon( self, FindItem( "Alien Disruptor" ) ))
+	{
+		self->accuracy = self->weapacc[ACCURACY_DISRUPTOR];
 		return;
 	}
 
-	if(ACEIT_ChangeWeapon(self,FindItem("Blaster")))
-   	{
-		self->accuracy = self->weapacc[1];
-		return;
-	}
-
-	return;
+	selected = ACEIT_ChangeWeapon( self, FindItem( "Blaster" ) );
+	assert( selected );
+	self->accuracy = self->weapacc[ACCURACY_BLASTER];
 
 }
