@@ -17,6 +17,11 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "g_local.h"
 #include "m_player.h"
 
@@ -44,7 +49,7 @@ qboolean OnSameTeam (edict_t *ent1, edict_t *ent2)
 	char	ent1Team [512];
 	char	ent2Team [512];
 
-	if ((!((int)(dmflags->value) & (DF_SKINTEAMS))) && !ctf->value && !tca->value && !cp->value)
+	if (!((dmflags->integer & DF_SKINTEAMS) || ctf->value || tca->value || cp->value))
 		return false;
 
 	strcpy (ent1Team, ClientTeam (ent1));
@@ -172,12 +177,12 @@ void Cmd_Give_f (edict_t *ent)
 
 	name = gi.args();
 
-	if (Q_stricmp(name, "all") == 0)
+	if (Q_strcasecmp(name, "all") == 0)
 		give_all = true;
 	else
 		give_all = false;
 
-	if (give_all || Q_stricmp(gi.argv(1), "health") == 0)
+	if (give_all || Q_strcasecmp(gi.argv(1), "health") == 0)
 	{
 		if (gi.argc() == 3)
 			ent->health = atoi(gi.argv(2));
@@ -187,7 +192,7 @@ void Cmd_Give_f (edict_t *ent)
 			return;
 	}
 
-	if (give_all || Q_stricmp(name, "weapons") == 0)
+	if (give_all || Q_strcasecmp(name, "weapons") == 0)
 	{
 		for (i=0 ; i<game.num_items ; i++)
 		{
@@ -202,7 +207,7 @@ void Cmd_Give_f (edict_t *ent)
 			return;
 	}
 
-	if (give_all || Q_stricmp(name, "ammo") == 0)
+	if (give_all || Q_strcasecmp(name, "ammo") == 0)
 	{
 		for (i=0 ; i<game.num_items ; i++)
 		{
@@ -217,7 +222,7 @@ void Cmd_Give_f (edict_t *ent)
 			return;
 	}
 
-	if (give_all || Q_stricmp(name, "armor") == 0)
+	if (give_all || Q_strcasecmp(name, "armor") == 0)
 	{
 		gitem_armor_t	*info;
 
@@ -702,7 +707,7 @@ void Cmd_Players_f (edict_t *ent)
 	int		index[256];
 
 	count = 0;
-	for (i = 0 ; i < maxclients->value ; i++)
+	for (i = 0 ; i < g_maxclients->value ; i++)
 		if (game.clients[i].pers.connected)
 		{
 			index[count] = i;
@@ -806,7 +811,7 @@ void Cmd_Say_f (edict_t *ent, qboolean team, qboolean arg0)
 	gi.WritePosition (ent->s.origin);
 	gi.multicast (ent->s.origin, MULTICAST_PVS);
 
-	if (!((((int)(dmflags->value) & (DF_SKINTEAMS))) || ctf->value || tca->value || cp->value))
+	if (!((dmflags->integer & DF_SKINTEAMS) || ctf->value || tca->value || cp->value))
 		team = false;
 
 	if (team)
@@ -861,7 +866,7 @@ void Cmd_Say_f (edict_t *ent, qboolean team, qboolean arg0)
 		cl->flood_when[cl->flood_whenhead] = level.time;
 	}
 
-	if (dedicated->value)
+	if (g_dedicated->value)
 		safe_cprintf(NULL, PRINT_CHAT, "%s", text);
 
 	for (j = 1; j <= game.maxclients; j++)
@@ -894,7 +899,7 @@ void Cmd_PlayerList_f(edict_t *ent)
 
 	// connect time, ping, score, name
 	*text = 0;
-	for (i = 0, e2 = g_edicts + 1; i < maxclients->value; i++, e2++) {
+	for (i = 0, e2 = g_edicts + 1; i < g_maxclients->value; i++, e2++) {
 		if (!e2->inuse)
 			continue;
 
@@ -934,11 +939,11 @@ void Cmd_CallVote_f (edict_t *ent)
 	}
 
 	//start a vote
-	playervote.called = true; 
+	playervote.called = true;
 	playervote.yay = playervote.nay = 0;
 	playervote.starttime = level.time;
 	if(strlen(gi.args()) < 128) {
-		strcpy(playervote.command, gi.args()); 
+		strcpy(playervote.command, gi.args());
 		safe_bprintf(PRINT_HIGH, "%s called a vote: %s\n", ent->client->pers.netname, playervote.command);
 	}
 }
@@ -991,7 +996,7 @@ void Cmd_Vote_f (edict_t *ent)
 	winner = 1; //next map in line
 	for(i = 0; i < 4; i++)
 		votedmap[i].tally = 0;
-	for (i=0 ; i<maxclients->value ; i++)
+	for (i=0 ; i<g_maxclients->value ; i++)
 	{
 		cl_ent = g_edicts + 1 + i;
 		if (!cl_ent->inuse || cl_ent->is_bot)
@@ -1051,7 +1056,7 @@ void Cmd_Vote_f (edict_t *ent)
 		sprintf( buffer, "Map %s leads with %i vote%s!", votedmap[winner].mapname, votedmap[winner].tally, (mostvotes > 1) ? "s" : "" );
 	}
 
-	for (i=0 ; i<maxclients->value ; i++)
+	for (i=0 ; i<g_maxclients->value ; i++)
 	{
 		cl_ent = g_edicts + 1 + i;
 		if (!cl_ent->inuse || cl_ent->is_bot)
@@ -1087,7 +1092,7 @@ void Cmd_VoiceTaunt_f (edict_t *ent)
 			strcpy(name, ent->client->pers.netname);
 			info = Info_ValueForKey (ent->client->pers.userinfo, "skin");
 			info[96] = 0; //truncate to prevent bad people from harming the server
-			
+
 			i = 0;
 			done = false;
 			while(!done)
@@ -1103,7 +1108,7 @@ void Cmd_VoiceTaunt_f (edict_t *ent)
 
 			sprintf(tauntsound, "taunts/%s/taunt%i.wav", playermodel, index);
 
-			Com_sprintf(string, sizeof(string), 
+			Com_sprintf(string, sizeof(string),
 				"%s %s %s ", info, tauntsound, name);
 
 			//send to all clients as a general config string
@@ -1131,42 +1136,42 @@ void ClientCommand (edict_t *ent)
 
 	cmd = gi.argv(0);
 
-	if (Q_stricmp (cmd, "players") == 0)
+	if (Q_strcasecmp (cmd, "players") == 0)
 	{
 		Cmd_Players_f (ent);
 		return;
 	}
-	if (Q_stricmp (cmd, "say") == 0)
+	if (Q_strcasecmp (cmd, "say") == 0)
 	{
 		Cmd_Say_f (ent, false, false);
 		return;
 	}
-	if (Q_stricmp (cmd, "say_team") == 0)
+	if (Q_strcasecmp (cmd, "say_team") == 0)
 	{
 		Cmd_Say_f (ent, true, false);
 		return;
 	}
-	if (Q_stricmp (cmd, "score") == 0)
+	if (Q_strcasecmp (cmd, "score") == 0)
 	{
 		Cmd_Score_f (ent);
 		return;
 	}
-	if (Q_stricmp (cmd, "help") == 0)
+	if (Q_strcasecmp (cmd, "help") == 0)
 	{
 		Cmd_Help_f (ent);
 		return;
 	}
-	if (Q_stricmp (cmd, "callvote") == 0)
+	if (Q_strcasecmp (cmd, "callvote") == 0)
 	{
 		Cmd_CallVote_f(ent);
 		return;
 	}
-	if (Q_stricmp (cmd, "vote") == 0)
+	if (Q_strcasecmp (cmd, "vote") == 0)
 	{
 		Cmd_Vote_f(ent);
 		return;
 	}
-	if	(Q_stricmp (cmd, "vtaunt") == 0)
+	if	(Q_strcasecmp (cmd, "vtaunt") == 0)
 	{
 		Cmd_VoiceTaunt_f(ent);
 		return;
@@ -1175,51 +1180,51 @@ void ClientCommand (edict_t *ent)
 	if (level.intermissiontime)
 		return;
 
-	if (Q_stricmp (cmd, "use") == 0)
+	if (Q_strcasecmp (cmd, "use") == 0)
 		Cmd_Use_f (ent);
-	else if (Q_stricmp (cmd, "drop") == 0)
+	else if (Q_strcasecmp (cmd, "drop") == 0)
 		Cmd_Drop_f (ent);
-	else if (Q_stricmp (cmd, "give") == 0)
+	else if (Q_strcasecmp (cmd, "give") == 0)
 		Cmd_Give_f (ent);
-	else if (Q_stricmp (cmd, "god") == 0)
+	else if (Q_strcasecmp (cmd, "god") == 0)
 		Cmd_God_f (ent);
-	else if (Q_stricmp (cmd, "notarget") == 0)
+	else if (Q_strcasecmp (cmd, "notarget") == 0)
 		Cmd_Notarget_f (ent);
-	else if (Q_stricmp (cmd, "noclip") == 0)
+	else if (Q_strcasecmp (cmd, "noclip") == 0)
 		Cmd_Noclip_f (ent);
-	else if (Q_stricmp (cmd, "inven") == 0)
+	else if (Q_strcasecmp (cmd, "inven") == 0)
 		Cmd_Inven_f (ent);
-	else if (Q_stricmp (cmd, "invnext") == 0)
+	else if (Q_strcasecmp (cmd, "invnext") == 0)
 		SelectNextItem (ent, -1);
-	else if (Q_stricmp (cmd, "invprev") == 0)
+	else if (Q_strcasecmp (cmd, "invprev") == 0)
 		SelectPrevItem (ent, -1);
-	else if (Q_stricmp (cmd, "invnextw") == 0)
+	else if (Q_strcasecmp (cmd, "invnextw") == 0)
 		SelectNextItem (ent, IT_WEAPON);
-	else if (Q_stricmp (cmd, "invprevw") == 0)
+	else if (Q_strcasecmp (cmd, "invprevw") == 0)
 		SelectPrevItem (ent, IT_WEAPON);
-	else if (Q_stricmp (cmd, "invnextp") == 0)
+	else if (Q_strcasecmp (cmd, "invnextp") == 0)
 		SelectNextItem (ent, IT_POWERUP);
-	else if (Q_stricmp (cmd, "invprevp") == 0)
+	else if (Q_strcasecmp (cmd, "invprevp") == 0)
 		SelectPrevItem (ent, IT_POWERUP);
-	else if (Q_stricmp (cmd, "invuse") == 0)
+	else if (Q_strcasecmp (cmd, "invuse") == 0)
 		Cmd_InvUse_f (ent);
-	else if (Q_stricmp (cmd, "invdrop") == 0)
+	else if (Q_strcasecmp (cmd, "invdrop") == 0)
 		Cmd_InvDrop_f (ent);
-	else if (Q_stricmp (cmd, "weapprev") == 0)
+	else if (Q_strcasecmp (cmd, "weapprev") == 0)
 		Cmd_WeapPrev_f (ent);
-	else if (Q_stricmp (cmd, "weapnext") == 0)
+	else if (Q_strcasecmp (cmd, "weapnext") == 0)
 		Cmd_WeapNext_f (ent);
-	else if (Q_stricmp (cmd, "weaplast") == 0)
+	else if (Q_strcasecmp (cmd, "weaplast") == 0)
 		Cmd_WeapLast_f (ent);
-	else if (Q_stricmp (cmd, "kill") == 0)
+	else if (Q_strcasecmp (cmd, "kill") == 0)
 		Cmd_Kill_f (ent);
-	else if (Q_stricmp (cmd, "putaway") == 0)
+	else if (Q_strcasecmp (cmd, "putaway") == 0)
 		Cmd_PutAway_f (ent);
-	else if (Q_stricmp (cmd, "wave") == 0)
+	else if (Q_strcasecmp (cmd, "wave") == 0)
 		Cmd_Wave_f (ent);
-	else if (Q_stricmp(cmd, "playerlist") == 0)
+	else if (Q_strcasecmp(cmd, "playerlist") == 0)
 		Cmd_PlayerList_f(ent);
-	else if (Q_stricmp (cmd, "chatbubble") == 0)
+	else if (Q_strcasecmp (cmd, "chatbubble") == 0)
 		DrawChatBubble(ent);
 	else	// anything that doesn't match a command will be a chat
 		Cmd_Say_f (ent, false, true);
