@@ -979,7 +979,7 @@ void SpawnItem (edict_t *ent, gitem_t *item)
 				return;
 			}
 		}
-		if(excessive->value || instagib->value || rocket_arena->value)
+		if(excessive->value || instagib->value || rocket_arena->value || insta_rockets->value )
 		{
 			if (item->flags == IT_AMMO || (strcmp(ent->classname, "weapon_bfg") == 0) ||
 				(strcmp(ent->classname, "weapon_hyperblaster") == 0) ||
@@ -1357,7 +1357,7 @@ always owned, never in the world
 		CTFWeapon_Grapple,
 		"misc/w_pkup.wav",
 		NULL, 0,
-		"vehicles/deathball/v_wep.md2",
+		"models/weapons/v_machn/tris.md2",
 /* icon */		"grapple",
 /* pickup */	"Grapple",
 		0,
