@@ -594,8 +594,10 @@ void TossClientWeapon (edict_t *self)
 	qboolean	haste;
 	float		spread;
 
-	if ((!deathmatch->value) || instagib->value || rocket_arena->value)
+	if ((!deathmatch->value) || instagib->value || rocket_arena->value || insta_rockets->value)
+	{
 		return;
+	}
 
 	item = self->client->pers.weapon;
 	if (! self->client->pers.inventory[self->client->ammo_index] )
@@ -764,7 +766,7 @@ void player_die (edict_t *self, edict_t *inflictor, edict_t *attacker, int damag
 			if (self->client->pers.inventory[ITEM_INDEX(flag1_item)] || self->client->pers.inventory[ITEM_INDEX(flag1_item)])
 				hasFlag = true;
 
-			CTFDeadDropFlag(self);
+			CTFDeadDropFlag(self, attacker);
 			if(anticamp->value && meansOfDeath == MOD_SUICIDE && hasFlag) {
 
 				//make campers really pay for hiding flags
@@ -967,6 +969,15 @@ void InitClientPersistant (gclient_t *client)
 		client->pers.inventory[ITEM_INDEX(FindItem("rockets"))] = g_maxrockets->value;
 		item = FindItem("Rocket Launcher");
 	}
+	else if ( insta_rockets->integer )
+	{
+		client->pers.inventory[ITEM_INDEX(FindItem("Rocket Launcher"))] = 1;
+		client->pers.inventory[ITEM_INDEX(FindItem("rockets"))] = g_maxrockets->value;
+		item = FindItem("Rocket Launcher");
+		client->pers.inventory[ITEM_INDEX(FindItem("Alien Disruptor"))] = 1;
+		client->pers.inventory[ITEM_INDEX(FindItem("cells"))] = g_maxcells->value;
+		item = FindItem("Alien Disruptor");
+	}
 	else
 		item = FindItem("Blaster");
 
@@ -1453,8 +1464,8 @@ void BodySink( edict_t *ent ) {
 }
 
 void body_die (edict_t *self, edict_t *inflictor, edict_t *attacker, int damage, vec3_t point)
-{   
-	self->s.modelindex3 = 0;    
+{
+	self->s.modelindex3 = 0;
 	self->s.modelindex4 = 0;
 
 	self->takedamage = DAMAGE_NO;
@@ -1475,7 +1486,7 @@ void body_die (edict_t *self, edict_t *inflictor, edict_t *attacker, int damage,
 	}
 
 	gi.linkentity (self);
-         
+
   }
 
 
@@ -1737,6 +1748,9 @@ void PutClientInServer (edict_t *ent)
 
 	//anti-camp
 	ent->suicide_timeout = level.time + 10.0;
+	VectorClear (ent->velocity_accum);
+	ent->old_velocities_current = -1;
+	ent->old_velocities_count = 0;
 
 	VectorCopy (mins, ent->mins);
 	VectorCopy (maxs, ent->maxs);
@@ -1755,18 +1769,11 @@ void PutClientInServer (edict_t *ent)
 	if(ent->client->chasecam)
 		G_FreeEdict (ent->client->chasecam);
 
-	if (deathmatch->value && (dmflags->integer & DF_FIXED_FOV))
-	{
+	client->ps.fov = atoi(Info_ValueForKey(client->pers.userinfo, "fov"));
+	if (client->ps.fov < 1)
 		client->ps.fov = 90;
-	}
-	else
-	{
-		client->ps.fov = atoi(Info_ValueForKey(client->pers.userinfo, "fov"));
-		if (client->ps.fov < 1)
-			client->ps.fov = 90;
-		else if (client->ps.fov > 160)
-			client->ps.fov = 160;
-	}
+	else if (client->ps.fov > 160)
+		client->ps.fov = 160;
 
 	client->ps.gunindex = gi.modelindex(client->pers.weapon->view_model);
 
@@ -1809,7 +1816,8 @@ void PutClientInServer (edict_t *ent)
 	Q2_FindFile (modelpath, &file);
 	if(file) { //human
 		ent->ctype = 1;
-		if(classbased->value && !(rocket_arena->value || instagib->value || excessive->value)) {
+		if(classbased->value && !(rocket_arena->value || instagib->value || insta_rockets->value || excessive->value))
+		 {
 			ent->health = ent->max_health = client->pers.max_health = client->pers.health = 100;
 			armor_index = ITEM_INDEX(FindItem("Jacket Armor"));
 			client->pers.inventory[armor_index] += 30;
@@ -1827,15 +1835,18 @@ void PutClientInServer (edict_t *ent)
 		Q2_FindFile (modelpath, &file);
 		if(file) {
 			ent->ctype = 2;
-			if(classbased->value && !(rocket_arena->value || instagib->value || excessive->value)) {
+			if(classbased->value && !(rocket_arena->value || instagib->value || insta_rockets->value || excessive->value))
+			{
 				ent->health = ent->max_health = client->pers.max_health = client->pers.health = 85;
 				armor_index = ITEM_INDEX(FindItem("Combat Armor"));
 				client->pers.inventory[armor_index] += 175;
 			}
 			fclose(file);
 		}
-		else { //alien
-			if(classbased->value && !(rocket_arena->value || instagib->value || excessive->value)) {
+		else
+		{ //alien
+			if(classbased->value && !(rocket_arena->value || instagib->value || insta_rockets->value || excessive->value))
+			{
 				ent->health = ent->max_health = client->pers.max_health = client->pers.health = 150;
 				client->pers.inventory[ITEM_INDEX(FindItem("Alien Disruptor"))] = 1;
 				client->pers.inventory[ITEM_INDEX(FindItem("cells"))] = 100;
@@ -1980,6 +1991,56 @@ void MoveClientsDownQueue(edict_t *ent)
 		ent->client->pers.queue = 0;
 }
 
+
+#define MAX_MOTD_SIZE	500
+
+/** @brief Read the MOTD file and send it to the client
+ *
+ * Try to open the MOTD file (first from the CVar setting, then from the
+ * default location). If it is found, read it and send it to the client.
+ *
+ * @param ent the entity to send to
+ *
+ * @return true if the message was found and sent
+ */
+static qboolean SendMessageOfTheDay( edict_t * ent )
+{
+	FILE		*file;
+	char		name[ MAX_OSPATH ];
+	qboolean	found;
+	int		size;
+	char		motd[ MAX_MOTD_SIZE ];
+
+	found = false;
+	if ( motdfile && motdfile->string && motdfile->string[0] ) {
+		// look for custom message of the day file
+		found = gi.FullPath( name, sizeof( name ),
+				motdfile->string );
+	}
+	if ( !found ) {
+		// look for default message of the day file
+		found = gi.FullPath( name, sizeof( name ), "motd.txt" );
+	}
+	if ( !found || (file = fopen( name, "rb" )) == NULL ) {
+		// No MOTD at all, or we can't read it
+		return false;
+	}
+
+	// We successfully opened the file "motd.txt" - read it and close it
+	size = fread( motd , 1 , MAX_MOTD_SIZE - 1 , file );
+	fclose( file );
+
+	// Make sure what we read is NULL-terminated
+	motd[ size ] = 0;
+
+	// If the file did contain data, print to the client
+	if ( size ) {
+		gi.centerprintf( ent , "%s" , motd );
+	}
+	return ( size > 0 );
+}
+
+
 /*
 =====================
 ClientBeginDeathmatch
@@ -1990,13 +2051,6 @@ deathmatch mode, so clear everything out before starting them.
 */
 void ClientBeginDeathmatch (edict_t *ent)
 {
-
-	FILE	*motd_file;
-	char	motd_file_name[MAX_OSPATH];
-	qboolean motd_found;
-	char	line[80];
-	char	motd[500];
-
 	G_InitEdict (ent);
 
 	InitClientResp (ent->client);
@@ -2043,36 +2097,14 @@ void ClientBeginDeathmatch (edict_t *ent)
 
 	safe_bprintf (PRINT_HIGH, "%s entered the game\n", ent->client->pers.netname);
 
-	// get the name for the MOTD file
-	motd_found = false;
-	if ( motdfile && motdfile->string && motdfile->string[0] )
-	{ // look for custom message of the day file
-		motd_found = gi.FullPath( motd_file_name, sizeof( motd_file_name ), motdfile->string );
-	}
-	if ( !motd_found )
-	{ // look for default message of the day file
-		motd_found = gi.FullPath( motd_file_name, sizeof( motd_file_name ), "motd.txt" );
-	}
-	if ( motd_found && (motd_file = fopen(motd_file_name, "rb")) != NULL )
-	{
-		// we successfully opened the file "motd.txt"
-		if ( fgets(motd, 500, motd_file) )
-		{
-			// we successfully read a line from "motd.txt" into motd
-			// ... read the remaining lines now
-			while ( fgets(line, 80, motd_file) )
-			{
-				// add each new line to motd, to create a BIG message string.
-				// we are using strcat: STRing conCATenation function here.
-				strcat(motd, line);
-			}
-
-			// print our message.
-			gi.centerprintf (ent, motd);
+	// Send MOTD and enable MOTD protection if necessary
+	if ( SendMessageOfTheDay( ent ) ) {
+		ent->client->motd_frames = motdforce->integer;
+		if ( ent->client->motd_frames < 0 ) {
+			ent->client->motd_frames = 0;
 		}
-		// be good now ! ... close the file
-		fclose(motd_file);
-
+	} else {
+		ent->client->motd_frames = 0;
 	}
 
 	if(g_callvote->value)
@@ -2107,7 +2139,7 @@ void ClientBegin (edict_t *ent)
 
 	ent->client = game.clients + (ent - g_edicts - 1);
 
-	for(i = 0; i < 8; i++) {
+	for(i = 0; i < 9; i++) {
 		ent->client->resp.weapon_shots[i] = 0;
 		ent->client->resp.weapon_hits[i] = 0;
 	}
@@ -2342,18 +2374,11 @@ void ClientUserinfoChanged (edict_t *ent, char *userinfo, int whereFrom)
 	}
 
 	// fov
-	if (deathmatch->value && (dmflags->integer & DF_FIXED_FOV))
-	{
+	ent->client->ps.fov = atoi(Info_ValueForKey(userinfo, "fov"));
+	if (ent->client->ps.fov < 1)
 		ent->client->ps.fov = 90;
-	}
-	else
-	{
-		ent->client->ps.fov = atoi(Info_ValueForKey(userinfo, "fov"));
-		if (ent->client->ps.fov < 1)
-			ent->client->ps.fov = 90;
-		else if (ent->client->ps.fov > 160)
-			ent->client->ps.fov = 160;
-	}
+	else if (ent->client->ps.fov > 160)
+		ent->client->ps.fov = 160;
 
 	// handedness
 	s = Info_ValueForKey (userinfo, "hand");
@@ -2453,18 +2478,11 @@ void ClientChangeSkin (edict_t *ent)
 	gi.configstring (CS_PLAYERSKINS+playernum, va("%s\\%s", ent->client->pers.netname, s) );
 
 	// fov
-	if (deathmatch->value && (dmflags->integer & DF_FIXED_FOV))
-	{
+	ent->client->ps.fov = atoi(Info_ValueForKey(userinfo, "fov"));
+	if (ent->client->ps.fov < 1)
 		ent->client->ps.fov = 90;
-	}
-	else
-	{
-		ent->client->ps.fov = atoi(Info_ValueForKey(userinfo, "fov"));
-		if (ent->client->ps.fov < 1)
-			ent->client->ps.fov = 90;
-		else if (ent->client->ps.fov > 160)
-			ent->client->ps.fov = 160;
-	}
+	else if (ent->client->ps.fov > 160)
+		ent->client->ps.fov = 160;
 
 	// handedness
 	s = Info_ValueForKey (userinfo, "hand");
@@ -2590,7 +2608,9 @@ void ClientDisconnect (edict_t *ent)
 	safe_bprintf (PRINT_HIGH, "%s disconnected\n", ent->client->pers.netname);
 
     if(ctf->value)
-		CTFDeadDropFlag(ent);
+    { //if carrying flag, don't take it with you! no attacker points.
+		CTFDeadDropFlag(ent, NULL);
+    }
 
 	DeadDropDeathball(ent);
 
@@ -2824,6 +2844,91 @@ void TeamCensus( teamcensus_t *teamcensus )
 }
 
 
+/** @brief Handle clients that are in "team selection" mode
+ *
+ * @todo this function needs cleaning up - if we set spectator mode to 0, we
+ *	can return from the function; if that is done, then we no longer need
+ *	to make sure that the client is not in a team in the rest of the
+ *	function.
+ *
+ * @param ent entity of the client
+ * @param client the client itself
+ * @param ucmd user command from the client
+ */
+static inline void ClientTeamSelection( edict_t * ent ,
+		gclient_t * client ,
+		usercmd_t * ucmd )
+{
+	teamcensus_t teamcensus;
+
+	if ( client->pers.spectator == 2 )
+	{ // entered with special team spectator mode on
+		// force it off, does not appear to help much. (?)
+		ent->dmteam = NO_TEAM;
+		client->pers.spectator = 0;
+	}
+
+	if ( ent->dmteam == RED_TEAM || ent->dmteam == BLUE_TEAM )
+	{
+		client->pers.spectator = 0;
+	}
+
+	if ( level.time / 2 == ceil( level.time / 2 )
+			&& client->pers.spectator == 1
+			&& ent->dmteam == NO_TEAM ) {
+		// send "how to join" message
+		if ( g_autobalance->integer )
+		{
+			safe_centerprintf( ent,
+				"\n\n\nPress <fire> to join\n"
+				"autobalanced team\n" );
+		}
+		else
+		{
+			safe_centerprintf( ent,
+				"\n\n\nPress <fire> to autojoin\n"
+				"or <jump> to join BLUE\n"
+				"or <crouch> to join RED\n" );
+		}
+	}
+
+	if ( client->latched_buttons & BUTTON_ATTACK )
+	{ // <fire> to auto join
+		client->latched_buttons = 0;
+		if ( client->pers.spectator == 1 && ent->dmteam == NO_TEAM)
+		{
+			TeamCensus( &teamcensus ); // apply team balance rules
+			ent->dmteam = teamcensus.team_for_real;
+			client->pers.spectator = 0;
+			ClientChangeSkin( ent );
+		}
+	}
+
+	if ( ucmd->upmove >= 10 && ent->dmteam == NO_TEAM )
+	{
+		if ( !g_autobalance->integer )
+		{ // jump to join blue
+			ent->dmteam = BLUE_TEAM;
+			client->pers.spectator = 0;
+			ClientChangeSkin( ent );
+		}
+	}
+	else if ( ucmd->upmove < 0 && ent->dmteam == NO_TEAM )
+	{
+		if ( !g_autobalance->integer )
+		{ // crouch to join red
+			ent->dmteam = RED_TEAM;
+			client->pers.spectator = 0;
+			ClientChangeSkin( ent );
+		}
+	}
+	else
+	{
+		client->ps.pmove.pm_flags &= ~PMF_JUMP_HELD;
+	}
+}
+
+
 /*
 ==============
 ClientThink
@@ -2841,11 +2946,19 @@ void ClientThink (edict_t *ent, usercmd_t *ucmd)
 	pmove_t	pm;
 	qboolean sproing, haste;
 	vec3_t addspeed, forward, up, right;
-	teamcensus_t teamcensus;
 
 	level.current_entity = ent;
 	client = ent->client;
 
+	// If the MOTD is being forced on, decrease frame counter
+	// and re-send the file if necessary
+	if ( client->motd_frames ) {
+		if ( level.time - floor( level.time ) != 0 ) {
+			SendMessageOfTheDay( ent );
+		}
+		client->motd_frames --;
+	}
+
 	//unlagged
 	if ( g_antilag->integer)
 		client->attackTime = gi.Sys_Milliseconds();
@@ -2878,7 +2991,7 @@ void ClientThink (edict_t *ent, usercmd_t *ucmd)
 				}
 
 				j = random() * (n_candidates - 1);
-				strcpy(level.changemap, votedmap[map_candidates[j]].mapname);
+				level.changemap = votedmap[map_candidates[j]].mapname; 
 			}
 			else
 			{
@@ -2888,7 +3001,7 @@ void ClientThink (edict_t *ent, usercmd_t *ucmd)
 					i = (j + 1) % 4;
 					if ( votedmap[i].tally < mostvotes )
 						continue;
-					strcpy(level.changemap, votedmap[i].mapname);
+				    level.changemap = votedmap[i].mapname;
 					break;
 				}
 			}
@@ -3054,7 +3167,7 @@ void ClientThink (edict_t *ent, usercmd_t *ucmd)
 				gi.sound(ent, CHAN_VOICE, gi.soundindex("items/sproing.wav"), 1, ATTN_NORM, 0);
 				ent->velocity[2] += 400;
 			}
-			if(haste) {
+			if(haste && ucmd->forwardmove > 0) {
 				AngleVectors (ent->s.angles, addspeed, right, up);
 				addspeed[0] *= 400;
 				addspeed[1] *= 400;
@@ -3141,69 +3254,7 @@ void ClientThink (edict_t *ent, usercmd_t *ucmd)
 
 		if ( TEAM_GAME && client->resp.spectator < 2 )
 		{ // team selection state
-
-			if ( client->pers.spectator == 2 )
-			{ // entered with special team spectator mode on
-				// force it off, does not appear to help much. (?)
-				ent->dmteam = NO_TEAM;
-				client->pers.spectator = 0;
-			}
-
-			if ( ent->dmteam == RED_TEAM || ent->dmteam == BLUE_TEAM )
-			{
-				client->pers.spectator = 0;
-			}
-
-			if ( client->pers.spectator == 1 && ent->dmteam == NO_TEAM
-					&& (level.time / 2 == ceil( level.time / 2 )) )
-			{ // send "how to join" message
-				if ( g_autobalance->integer )
-				{
-					safe_centerprintf( ent, "\n\n\nPress <fire> to join\n"
-						"autobalanced team\n" );
-				}
-				else
-				{
-					safe_centerprintf( ent, "\n\n\nPress <fire> to autojoin\n"
-						"or <jump> to join BLUE\n"
-						"or <crouch> to join RED\n" );
-				}
-			}
-
-			if ( client->latched_buttons & BUTTON_ATTACK )
-			{ // <fire> to auto join
-				client->latched_buttons = 0;
-				if ( client->pers.spectator == 1 && ent->dmteam == NO_TEAM)
-				{
-					TeamCensus( &teamcensus ); // apply team balance rules
-					ent->dmteam = teamcensus.team_for_real;
-					client->pers.spectator = 0;
-					ClientChangeSkin( ent );
-				}
-			}
-
-			if ( ucmd->upmove >= 10 && ent->dmteam == NO_TEAM )
-			{
-				if ( !g_autobalance->integer )
-				{ // jump to join blue
-					ent->dmteam = BLUE_TEAM;
-					client->pers.spectator = 0;
-					ClientChangeSkin( ent );
-				}
-			}
-			else if ( ucmd->upmove < 0 && ent->dmteam == NO_TEAM )
-			{
-				if ( !g_autobalance->integer )
-				{ // crouch to join red
-					ent->dmteam = RED_TEAM;
-					client->pers.spectator = 0;
-					ClientChangeSkin( ent );
-				}
-			}
-			else
-			{
-				client->ps.pmove.pm_flags &= ~PMF_JUMP_HELD;
-			}
+			ClientTeamSelection( ent , client , ucmd );
 		} /* team selection state */
 		else
 		{ // regular spectator
@@ -3269,6 +3320,75 @@ void ClientThink (edict_t *ent, usercmd_t *ucmd)
 }
 
 
+/** @brief Update the anti-camp timeout
+ *
+ * The anti-camp computation accumulates players' velocities, averages them
+ * and updates the "suicide_timeout" field if the length of that average
+ * vector is above some threshold.
+ *
+ * It is controlled by the camptime, ac_frames and ac_threshold CVars.
+ */
+static inline void _UpdateAntiCamp( edict_t * ent )
+{
+	int n_frames = ac_frames->integer;
+	float thresh;
+	vec3_t avg;
+
+	// Make sure we have a valid ac_frames
+	if ( n_frames < 1 || n_frames > 100 ) {
+		n_frames = G_ANTICAMP_FRAMES;
+	}
+
+	if ( ent->old_velocities_count < n_frames ) {
+		// Not enough frames yet
+		ent->old_velocities_count ++;
+		ent->old_velocities_current ++;
+	} else {
+		// Enough frames - remove oldest known velocity from
+		// accumulator
+		ent->old_velocities_current = ( ent->old_velocities_current
+				+ 1 ) % n_frames;
+		VectorSubtract( ent->velocity_accum ,
+			ent->old_velocities[ ent->old_velocities_current ] ,
+			ent->velocity_accum );
+	}
+
+	// Store current velocity into history and add its value to the
+	// accumulator
+	VectorCopy( ent->velocity ,
+			ent->old_velocities[ ent->old_velocities_current ] );
+	VectorAdd( ent->velocity_accum , ent->velocity , ent->velocity_accum );
+	if ( ent->old_velocities_count < n_frames ) {
+		return;
+	}
+
+	// Get and adjust speed threshold
+	thresh = ac_threshold->value;
+	if ( thresh <= 0 || thresh > 500 ) {
+		thresh = G_ANTICAMP_THRESHOLD;
+	}
+	if ( excessive->integer ) {
+		thresh *= 1.5;
+	}
+
+	// Check average velocity lengths against threshold
+	VectorCopy( ent->velocity_accum , avg );
+	avg[0] /= n_frames; avg[1] /= n_frames; avg[2] /= n_frames;
+	if ( VectorLength( avg ) > thresh ) {
+		ent->suicide_timeout = level.time + camptime->integer;
+	}
+
+	// Inflict anti-camp damage
+	if ( ent->suicide_timeout < level.time && ent->takedamage == DAMAGE_AIM
+			&& ! ent->client->resp.spectator) {
+		T_Damage (ent, world, world, vec3_origin, ent->s.origin,
+				vec3_origin, ent->dmg, 0, DAMAGE_NO_ARMOR,
+				MOD_SUICIDE);
+		safe_centerprintf(ent, "Anticamp: move or die!\n");
+	}
+}
+
+
 /*
 ==============
 ClientBeginServerFrame
@@ -3312,20 +3432,11 @@ void ClientBeginServerFrame (edict_t *ent)
 	//end spectator mode
 
 	//anti-camp
-	if(anticamp->value) {
-		if(excessive->value) {
-			if(VectorLength(ent->velocity) > 450)
-				ent->suicide_timeout = level.time + camptime->integer;
-		}
-		else {
-			if(VectorLength(ent->velocity) > 300)
-				ent->suicide_timeout = level.time + camptime->integer;
-		}
-		if(ent->suicide_timeout < level.time && ent->takedamage == DAMAGE_AIM
-			&& !client->resp.spectator) {
-			T_Damage (ent, world, world, vec3_origin, ent->s.origin, vec3_origin, ent->dmg, 0, DAMAGE_NO_ARMOR, MOD_SUICIDE);
-			safe_centerprintf(ent, "Anticamp: move or die!\n");
-		}
+	// do not apply to godmode cheat or bots.
+	// bots have other suicidal tendencies which may (or may not) conflict.
+	if ( anticamp->integer && !(ent->flags & FL_GODMODE) && !(ent->is_bot) )
+	{
+		_UpdateAntiCamp( ent );
 	}
 
 	//spectator mode
