@@ -130,8 +130,10 @@ qboolean Pickup_Weapon (edict_t *ent, edict_t *other)
 	index = ITEM_INDEX(ent->item);
 
 	//mutators
-	if(instagib->value || rocket_arena->value)
+	if ( instagib->integer || rocket_arena->integer || insta_rockets->integer )
+	{
 		return false; //why pick them up in these modes?
+	}
 
 	if ( ( (dmflags->integer & DF_WEAPONS_STAY))
 		&& other->client->pers.inventory[index])
@@ -483,8 +485,11 @@ void Drop_Weapon (edict_t *ent, gitem_t *item)
 {
 	int		index;
 
-	if ((dmflags->integer & DF_WEAPONS_STAY) || instagib->value || rocket_arena->value)
+	if ((dmflags->integer & DF_WEAPONS_STAY) || instagib->integer
+		|| rocket_arena->integer || insta_rockets->integer )
+	{
 		return;
+	}
 
 	index = ITEM_INDEX(item);
 	// see if we're already using it
@@ -516,7 +521,7 @@ void Weapon_Generic (edict_t *ent, int FRAME_ACTIVATE_LAST, int FRAME_FIRE_LAST,
 
 	if (ent->client->weaponstate == WEAPON_DROPPING)
 	{
-		if(excessive->value || quickweap->value) {
+		if(excessive->value || quickweap->value || ent->client->invincible_framenum > level.framenum) {
 			ChangeWeapon (ent);
 			return;
 		}
@@ -532,7 +537,7 @@ void Weapon_Generic (edict_t *ent, int FRAME_ACTIVATE_LAST, int FRAME_FIRE_LAST,
 
 	if (ent->client->weaponstate == WEAPON_ACTIVATING)
 	{
-		if(excessive->value || quickweap->value) {
+		if(excessive->value || quickweap->value || ent->client->invincible_framenum > level.framenum) {
 			ent->client->weaponstate = WEAPON_READY;
 			ent->client->ps.gunframe = FRAME_IDLE_FIRST;
 			return;
@@ -687,7 +692,8 @@ void weapon_plasma_fire (edict_t *ent)
 	int		kick;
 	int		buildup;
 
-	if(instagib->value) {
+	if ( instagib->integer || insta_rockets->integer )
+	{
 		damage = 200;
 		kick = 200;
 	} else {
@@ -737,8 +743,12 @@ void weapon_plasma_fire (edict_t *ent)
 	ent->client->ps.gunframe++;
 	PlayerNoise(ent, start, PNOISE_WEAPON);
 
-	if (! ( (dmflags->integer & DF_INFINITE_AMMO) || instagib->integer ) )
-		ent->client->pers.inventory[ent->client->ammo_index]= ent->client->pers.inventory[ent->client->ammo_index]-5;
+	if ( !( (dmflags->integer & DF_INFINITE_AMMO) || instagib->integer
+		|| insta_rockets->integer ) )
+	{
+		ent->client->pers.inventory[ent->client->ammo_index] =
+				ent->client->pers.inventory[ent->client->ammo_index]-5;
+	}
 }
 
 void Weapon_Disruptor (edict_t *ent)
@@ -747,7 +757,7 @@ void Weapon_Disruptor (edict_t *ent)
 	static int	fire_frames[]	= {5, 0};
 	static int	excessive_fire_frames[] = {5,7,9,11,0};
 
-	if(excessive->value)
+	if(excessive->value || ent->client->invincible_framenum > level.framenum)
 		Weapon_Generic (ent, 4, 12, 42, 46, pause_frames, excessive_fire_frames, weapon_plasma_fire);
 	else
 		Weapon_Generic (ent, 4, 12, 42, 46, pause_frames, fire_frames, weapon_plasma_fire);
@@ -953,7 +963,8 @@ void Weapon_RocketLauncher_Fire (edict_t *ent)
 	float	damage_radius;
 	int		radius_damage;
 
-	damage = 100 + (int)(random() * 20.0);
+	// damage = 100 + (int)(random() * 20.0);
+	damage        = 110; // median of formerly random 100..120
 	radius_damage = 120;
 	damage_radius = 120;
 	if (is_quad)
@@ -996,8 +1007,10 @@ void Weapon_RocketLauncher_Fire (edict_t *ent)
 
 	PlayerNoise(ent, start, PNOISE_WEAPON);
 
-	if ((! ( dmflags->integer & DF_INFINITE_AMMO ) ) && !rocket_arena->value)
+	if ( (!( dmflags->integer & DF_INFINITE_AMMO )) && !rocket_arena->integer && !insta_rockets->integer )
+	{
 		ent->client->pers.inventory[ent->client->ammo_index]--;
+	}
 }
 
 void Weapon_RocketLauncher (edict_t *ent)
@@ -1006,7 +1019,7 @@ void Weapon_RocketLauncher (edict_t *ent)
 	static int	fire_frames[]	= {6, 0};
 	static int	excessive_fire_frames[]	= {5,7,9,11,13, 0};
 
-	if(excessive->value)
+	if(excessive->value || ent->client->invincible_framenum > level.framenum)
 		Weapon_Generic (ent, 5, 14, 52, 56, pause_frames, excessive_fire_frames, Weapon_RocketLauncher_Fire);
 	else
 		Weapon_Generic (ent, 5, 14, 52, 56, pause_frames, fire_frames, Weapon_RocketLauncher_Fire);
@@ -1106,7 +1119,7 @@ void Weapon_Blaster (edict_t *ent)
 	static int	fire_frames[]	= {5,0};
 	static int  excessive_fire_frames[] = {5,6,7,8,0};
 
-	if(excessive->value)
+	if(excessive->value || ent->client->invincible_framenum > level.framenum)
 		Weapon_Generic (ent, 4, 8, 52, 55, pause_frames, excessive_fire_frames, Weapon_Blaster_Fire);
 	else
 		Weapon_Generic (ent, 4, 8, 52, 55, pause_frames, fire_frames, Weapon_Blaster_Fire);
@@ -1169,7 +1182,7 @@ void Weapon_Bomber (edict_t *ent)
 	static int	fire_frames[]	= {6,12,0};
 	static int	excessive_fire_frames[]	= {6,8,10,12,0};
 
-	if(excessive->value)
+	if(excessive->value || ent->client->invincible_framenum > level.framenum)
 		Weapon_Generic (ent, 5, 16, 39, 45, pause_frames, excessive_fire_frames, Weapon_Bomber_Fire);
 	else
 		Weapon_Generic (ent, 5, 16, 39, 45, pause_frames, fire_frames, Weapon_Bomber_Fire);
@@ -1266,7 +1279,7 @@ void Weapon_Strafer (edict_t *ent) //for now
 	static int	fire_frames[]	= {6,0};
 	static int	excessive_fire_frames[]	= {6,8,10,0};
 
-	if(excessive->value)
+	if(excessive->value || ent->client->invincible_framenum > level.framenum)
 		Weapon_Generic (ent, 5, 11, 33, 39, pause_frames, excessive_fire_frames, Weapon_Strafer_Fire);
 	else
 		Weapon_Generic (ent, 5, 11, 33, 39, pause_frames, fire_frames, Weapon_Strafer_Fire);
@@ -1335,7 +1348,7 @@ void Weapon_Hover (edict_t *ent) //for now
 	static int	fire_frames[]	= {6,8,10,0};
 	static int	excessive_fire_frames[]	= {6,8,10,0};
 
-	if(excessive->value)
+	if(excessive->value || ent->client->invincible_framenum > level.framenum)
 		Weapon_Generic (ent, 5, 11, 33, 39, pause_frames, excessive_fire_frames, Weapon_Hover_Fire);
 	else
 		Weapon_Generic (ent, 5, 11, 33, 39, pause_frames, fire_frames, Weapon_Hover_Fire);
@@ -1530,6 +1543,14 @@ void Machinegun_Fire (edict_t *ent)
 
 	}
 	else if(!ent->altfire){
+		if (!(ent->client->buttons & BUTTON_ATTACK) && ent->client->ps.gunframe > 6) {
+			//Fast-forward through firing animation if not firing anymore.
+			//This is purely cosmetic, the player can resume firing at any
+			//point in this animation. 
+			//TODO: special sound effect here? 
+			ent->client->ps.gunframe+=2;
+			return; //Don't waste ammo
+		}
 		for (i=0 ; i<shots ; i++)
 		{
 			VectorSet(offset, 1, 1, ent->viewheight-0.5);
@@ -1580,7 +1601,8 @@ void weapon_floater_fire (edict_t *ent)
 	float	damage_radius;
 	int		radius_damage;
 
-	damage = 100 + (int)(random() * 20.0);
+	// damage = 100 + (int)(random() * 20.0);
+	damage        = 110; // median of formerly random damage of 100..120
 	radius_damage = 120;
 	damage_radius = 120;
 	if (is_quad || excessive->value)
@@ -1785,9 +1807,8 @@ void Violator_Fire (edict_t *ent)
 		VectorAdd(start, right, start);
 
 		gi.WriteByte (svc_temp_entity);
-		gi.WriteByte (TE_VOLTAGE);
+		gi.WriteByte (TE_BOSSTPORT);
 		gi.WritePosition (start);
-		gi.WriteDir(forward);
 		gi.multicast (start, MULTICAST_PVS);
 
 		gi.WriteByte (svc_temp_entity);
@@ -1799,7 +1820,7 @@ void Violator_Fire (edict_t *ent)
 		ent->client->ps.gunframe = 12;
 
 	}
-	else if(!ent->altfire){
+	else if(!ent->altfire) {
 
 		VectorSet(offset, 1, 1, ent->viewheight-0.5);
 		P_ProjectSource (ent->client, ent->s.origin, offset, forward, right, start);
@@ -1830,10 +1851,7 @@ void Violator_Fire (edict_t *ent)
 		gi.WriteByte (TE_BLUE_MUZZLEFLASH);
 		gi.WritePosition (start);
 		gi.multicast (start, MULTICAST_PVS);
-
-
 	}
-
 }
 
 void Weapon_Violator (edict_t *ent)
