@@ -8,7 +8,7 @@ of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 
 See the GNU General Public License for more details.
 
@@ -17,18 +17,17 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
-#include "q_shared.h"
 
-#define DEG2RAD( a ) ( a * M_PI ) / 180.0F   
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#include "q_shared.h"
 
 vec3_t vec3_origin = {0,0,0};
 
 //============================================================================
 
-#ifdef _WIN32
-#pragma optimize( "", off )
-#endif
-
 void RotatePointAroundVector( vec3_t dst, const vec3_t dir, const vec3_t point, float degrees )
 {
 	float	m[3][3];
@@ -84,26 +83,22 @@ void RotatePointAroundVector( vec3_t dst, const vec3_t dir, const vec3_t point,
 	}
 }
 
-#ifdef _WIN32
-#pragma optimize( "", on )
-#endif
-
 /*
 ** Fast sincos function using polynomial approximation
 **
 ** Profiling indicates that AngleVectors() is heavily used, which justifies
 **   (i hope) doing some "heroic" optimization.
-** Testing indicates that maximum variation from original calculation is 
+** Testing indicates that maximum variation from original calculation is
 **   is around 0.000006
 **
 ** sin(a) ~=  a - (0.16666 * a**3) + (0.0083143 a**5) - (0.00018542 * a**7)
-**   
+**
 ** Reference:
 **   Essential Mathematics for Games and Interactive Applications, Second Edition.
 **   by James M. Van Verth and Lars M. Bishop, Morgan-Kaufman Publishing.
 **   which bases this technique on:
 **   Robin Green's GDC 2003 session, "Faster Math Functions"
-** 
+**
 ** Arguments:
 **   angle : in radians
 */
@@ -122,9 +117,9 @@ float fast_sincosf_calc( float angle )
 {
 	float result;
 	float anglesq;
-	
+
 	anglesq = angle * angle;
-	result = angle * ( 1.0f + anglesq * (kpoly3 + anglesq * (kpoly5 
+	result = angle * ( 1.0f + anglesq * (kpoly3 + anglesq * (kpoly5
 		+ ( anglesq * kpoly7 ))));
 	return result;
 }
@@ -136,7 +131,7 @@ void fast_sincosf( float angle, float *sina, float *cosa )
 	float angle_float_part;
 	float angle_float_part_minus_halfpi;
 	int angle_int_part;
-	
+
 	// make negative angle non-negative for purposes of calculation
 	negate = false;
 	angle_radians = angle;
@@ -146,12 +141,12 @@ void fast_sincosf( float angle, float *sina, float *cosa )
 		angle_radians = -angle_radians;
 	}
 
-	// this is tricky. to prevent "catastophic cancelation" when subtracting 
+	// this is tricky. to prevent "catastophic cancelation" when subtracting
 	//  near equal floating point numbers, the calculation is broken down
 	//  into 2 parts.
 	angle_float_part =  kTwoOverPI * angle_radians;
 	angle_int_part = (int)angle_float_part;
-	angle_float_part = (angle_radians - (kRationalHalfPI * angle_int_part)) 
+	angle_float_part = (angle_radians - (kRationalHalfPI * angle_int_part))
 		- (kRemainderHalfPI * angle_int_part);
 	angle_float_part_minus_halfpi = (angle_float_part - kRationalHalfPI)
 		- kRemainderHalfPI;
@@ -180,18 +175,13 @@ void fast_sincosf( float angle, float *sina, float *cosa )
 	{
 		*sina = -(*sina);
 	}
-	
+
 }
 
 void AngleVectors (vec3_t angles, vec3_t forward, vec3_t right, vec3_t up)
 {
 	float		angle;
-#ifdef _WINDOWS	
-	static float		sr, sp, sy, cr, cp, cy;
-	// static to help MS compiler fp bugs
-#else
 	float		sr, sp, sy, cr, cp, cy;
-#endif	
 
 	angle = angles[YAW] * (kTwoPI / 360.0f);
 	fast_sincosf( angle, &sy, &cy );
@@ -224,6 +214,43 @@ void AngleVectors (vec3_t angles, vec3_t forward, vec3_t right, vec3_t up)
 }
 
 
+void vectoangles (vec3_t value1, vec3_t angles)
+{
+	float	forward;
+	float	yaw, pitch;
+
+	if (value1[1] == 0.0f && value1[0] == 0.0f )
+	{
+		yaw = 0.0f;
+		if (value1[2] > 0.0f)
+			pitch = 90.0f;
+		else
+			pitch = 270.0f;
+	}
+	else
+	{
+	// PMM - fixed to correct for pitch of 0
+		if (value1[0])
+			yaw = (atan2(value1[1], value1[0]) * 180.0f / M_PI);
+		else if (value1[1] > 0)
+			yaw = 90.0f;
+		else
+			yaw = 270.0f;
+
+		if (yaw < 0.0f)
+			yaw += 360.0f;
+
+		forward = sqrt (value1[0]*value1[0] + value1[1]*value1[1]);
+		pitch = (atan2(value1[2], forward) * 180.0f / M_PI);
+		if (pitch < 0.0f)
+			pitch += 360.0f;
+	}
+
+	angles[PITCH] = -pitch;
+	angles[YAW] = yaw;
+	angles[ROLL] = 0.0f;
+}
+
 void ProjectPointOnPlane( vec3_t dst, const vec3_t p, const vec3_t normal )
 {
 	float d;
@@ -345,6 +372,8 @@ void R_ConcatTransforms (float in1[3][4], float in2[3][4], float out[3][4])
 //============================================================================
 
 
+// these are probably obsolete (2010-06-13)
+/*
 float Q_fabs (float f)
 {
 #if 0
@@ -370,6 +399,7 @@ __declspec( naked ) long Q_ftol( float f )
 }
 #pragma warning (default:4035)
 #endif
+*/
 
 /*
 ===============
@@ -395,7 +425,7 @@ float	anglemod(float a)
 	else
 		a += 360*( 1 + (int)(-a/360) );
 #endif
-	a = (360.0/65536) * ((int)(a*(65536/360.0)) & 65535);
+	a = (360.0f/65536.0f) * ((int)(a*(65536.0f/360.0f)) & 65535);
 	return a;
 }
 
@@ -442,7 +472,7 @@ BoxOnPlaneSide
 Returns 1, 2, or 1 + 2
 ==================
 */
-#if !id386 || defined __unix__
+
 int BoxOnPlaneSide (vec3_t emins, vec3_t emaxs, struct cplane_s *p)
 {
 	float	dist1, dist2;
@@ -457,7 +487,7 @@ int BoxOnPlaneSide (vec3_t emins, vec3_t emaxs, struct cplane_s *p)
 			return 2;
 		return 3;
 	}
-	
+
 // general case
 	switch (p->signbits)
 	{
@@ -505,12 +535,10 @@ dist2 = p->normal[0]*emaxs[0] + p->normal[1]*emaxs[1] + p->normal[2]*emaxs[2];
 	if (dist2 < p->dist)
 		sides |= 2;
 
-//	assert( sides != 0 );
-//-JD - commented this out, it caused crashes on DM14.  Not even sure of it's purpose.
-
 	return sides;
 }
-#else
+
+/*  probably obsolete (2010-08)
 #pragma warning( disable: 4035 )
 
 __declspec( naked ) int BoxOnPlaneSide (vec3_t emins, vec3_t emaxs, struct cplane_s *p)
@@ -521,11 +549,11 @@ __declspec( naked ) int BoxOnPlaneSide (vec3_t emins, vec3_t emaxs, struct cplan
 	__asm {
 
 		push ebx
-			
+
 		cmp bops_initialized, 1
 		je  initialized
 		mov bops_initialized, 1
-		
+
 		mov Ljmptab[0*4], offset Lcase0
 		mov Ljmptab[1*4], offset Lcase1
 		mov Ljmptab[2*4], offset Lcase2
@@ -534,7 +562,7 @@ __declspec( naked ) int BoxOnPlaneSide (vec3_t emins, vec3_t emaxs, struct cplan
 		mov Ljmptab[5*4], offset Lcase5
 		mov Ljmptab[6*4], offset Lcase6
 		mov Ljmptab[7*4], offset Lcase7
-			
+
 initialized:
 
 		mov edx,ds:dword ptr[4+12+esp]
@@ -744,6 +772,7 @@ Lerror:
 }
 #pragma warning( default: 4035 )
 #endif
+*/
 
 void ClearBounds (vec3_t mins, vec3_t maxs)
 {
@@ -771,7 +800,7 @@ int VectorCompare (vec3_t v1, vec3_t v2)
 {
 	if (v1[0] != v2[0] || v1[1] != v2[1] || v1[2] != v2[2])
 			return 0;
-			
+
 	return 1;
 }
 
@@ -790,7 +819,7 @@ vec_t VectorNormalize (vec3_t v)
 		v[1] *= ilength;
 		v[2] *= ilength;
 	}
-		
+
 	return length;
 
 }
@@ -800,7 +829,7 @@ vec_t VectorNormalize2 (vec3_t v, vec3_t out)
 	float	length, ilength;
 
 	length = v[0]*v[0] + v[1]*v[1] + v[2]*v[2];
-	length = sqrt (length);		// FIXME
+	length = sqrt (length);
 
 	if (length)
 	{
@@ -809,7 +838,7 @@ vec_t VectorNormalize2 (vec3_t v, vec3_t out)
 		out[1] = v[1]*ilength;
 		out[2] = v[2]*ilength;
 	}
-		
+
 	return length;
 
 }
@@ -889,17 +918,15 @@ void CrossProduct (vec3_t v1, vec3_t v2, vec3_t cross)
 	cross[2] = v1[0]*v2[1] - v1[1]*v2[0];
 }
 
-double sqrt(double x);
-
 vec_t VectorLength(vec3_t v)
 {
 	int		i;
 	float	length;
-	
+
 	length = 0;
 	for (i=0 ; i< 3 ; i++)
 		length += v[i]*v[i];
-	length = sqrt (length);		// FIXME
+	length = sqrt (length);
 
 	return length;
 }
@@ -939,7 +966,7 @@ COM_SkipPath
 char *COM_SkipPath (char *pathname)
 {
 	char	*last;
-	
+
 	last = pathname;
 	while (*pathname)
 	{
@@ -962,13 +989,17 @@ void COM_StripExtension (char *in, char *out)
 	*out = 0;
 }
 
+
 /*
 ============
 COM_FileExtension
 ============
 */
+#if 0
+// not used
 char *COM_FileExtension (char *in)
 {
+
 	static char exten[8];
 	int		i;
 
@@ -982,6 +1013,7 @@ char *COM_FileExtension (char *in)
 	exten[i] = 0;
 	return exten;
 }
+#endif
 
 /*
 ============
@@ -991,15 +1023,15 @@ COM_FileBase
 void COM_FileBase (char *in, char *out)
 {
 	char *s, *s2;
-	
+
 	s = in + strlen(in) - 1;
-	
+
 	while (s != in && *s != '.')
 		s--;
-	
+
 	for (s2 = s ; s2 != in && *s2 != '/' ; s2--)
 	;
-	
+
 	if (s-s2 < 2)
 		out[0] = 0;
 	else
@@ -1020,9 +1052,9 @@ Returns the path up to, but not including the last /
 void COM_FilePath (char *in, char *out)
 {
 	char *s;
-	
+
 	s = in + strlen(in) - 1;
-	
+
 	while (s != in && *s != '/')
 		s--;
 
@@ -1120,8 +1152,8 @@ float FloatSwap (float f)
 		float	f;
 		byte	b[4];
 	} dat1, dat2;
-	
-	
+
+
 	dat1.f = f;
 	dat2.b[0] = dat1.b[3];
 	dat2.b[1] = dat1.b[2];
@@ -1144,7 +1176,7 @@ void Swap_Init (void)
 {
 	byte	swaptest[2] = {1,0};
 
-// set the byte swapping variables in a portable manner	
+// set the byte swapping variables in a portable manner
 	if ( *(short *)swaptest == 1)
 	{
 		bigendien = false;
@@ -1179,16 +1211,22 @@ varargs versions of all text functions.
 FIXME: make this buffer size safe someday
 ============
 */
+/*
+ * 2010-11 Use multiple static buffers to avoid collisions.
+ *  Like g_utils::tv(),vtos()
+ */
 char	*va(char *format, ...)
 {
 	va_list		argptr;
-	static char		string[1024];
-	
+	static int index = 0;
+	static char string[8][1024];
+
+	index = (index + 1) & 0x07;
 	va_start (argptr, format);
-	vsnprintf(string, sizeof(string), format, argptr);
+	vsnprintf(string[index], sizeof(string[0]), format, argptr);
 	va_end (argptr);
 
-	return string;	
+	return string[index];
 }
 
 
@@ -1210,13 +1248,13 @@ char *COM_Parse (char **data_p)
 	data = *data_p;
 	len = 0;
 	com_token[0] = 0;
-	
+
 	if (!data)
 	{
 		*data_p = NULL;
 		return "";
 	}
-		
+
 // skip whitespace
 skipwhite:
 	while ( (c = *data) <= ' ')
@@ -1228,7 +1266,7 @@ skipwhite:
 		}
 		data++;
 	}
-	
+
 // skip // comments
 	if (c=='/' && data[1] == '/')
 	{
@@ -1282,207 +1320,207 @@ skipwhite:
 }
 
 int Q_strnicmp (const char *string1, const char *string2, int n)
-{ 
-	int c1, c2; 
-	 
+{
+	int c1, c2;
+
 	if (string1 == NULL)
-	{ 
-		if (string2 == NULL) 
-			return 0; 
-		else 
-			return -1; 
-	} 
-	else if (string2 == NULL) 
-		return 1; 
-	 
-	do 
-	{ 
-		c1 = *string1++; 
-		c2 = *string2++; 
-		 
-		if (!n--) 
-			return 0;// Strings are equal until end point 
-		 
+	{
+		if (string2 == NULL)
+			return 0;
+		else
+			return -1;
+	}
+	else if (string2 == NULL)
+		return 1;
+
+	do
+	{
+		c1 = *string1++;
+		c2 = *string2++;
+
+		if (!n--)
+			return 0;// Strings are equal until end point
+
 		if (c1 != c2)
-		{ 
-			if (c1 >= 'a' && c1 <= 'z') 
-				c1 -= ('a' - 'A'); 
-			if (c2 >= 'a' && c2 <= 'z') 
-				c2 -= ('a' - 'A'); 
-			 
-			if (c1 != c2) 
-				return c1 < c2 ? -1 : 1; 
-		} 
-	} while (c1); 
-	 
-	return 0;// Strings are equal 
+		{
+			if (c1 >= 'a' && c1 <= 'z')
+				c1 -= ('a' - 'A');
+			if (c2 >= 'a' && c2 <= 'z')
+				c2 -= ('a' - 'A');
+
+			if (c1 != c2)
+				return c1 < c2 ? -1 : 1;
+		}
+	} while (c1);
+
+	return 0;// Strings are equal
 }
 void Q_strncpyz2 (char *dst, const char *src, int dstSize)
 {
-	if (!dst) 
-		Sys_Error(ERR_FATAL, "Q_strncpyz: NULL dst"); 
-		
-	if (!src) 
-		Sys_Error(ERR_FATAL, "Q_strncpyz: NULL src"); 
-		
-	if (dstSize < 1) 
-		Sys_Error(ERR_FATAL, "Q_strncpyz: dstSize < 1"); 
-		
-	strncpy(dst, src, dstSize-1); 
-	dst[dstSize-1] = 0; 
+	if (!dst)
+		Sys_Error(ERR_FATAL, "Q_strncpyz: NULL dst");
+
+	if (!src)
+		Sys_Error(ERR_FATAL, "Q_strncpyz: NULL src");
+
+	if (dstSize < 1)
+		Sys_Error(ERR_FATAL, "Q_strncpyz: dstSize < 1");
+
+	strncpy(dst, src, dstSize-1);
+	dst[dstSize-1] = 0;
 }
 
 void Q_strcat (char *dst, const char *src, int dstSize)
-{ 
-	 
-	int len; 
-	 
-	len = strlen(dst); 
-	if (len >= dstSize) 
-		Sys_Error(ERR_FATAL, "Q_strcat: already overflowed"); 
-	 
-	Q_strncpyz2(dst + len, src, dstSize - len); 
+{
+
+	int len;
+
+	len = strlen(dst);
+	if (len >= dstSize)
+		Sys_Error(ERR_FATAL, "Q_strcat: already overflowed");
+
+	Q_strncpyz2(dst + len, src, dstSize - len);
 }
 
 char *Com_SkipWhiteSpace (char *data_p, qboolean *hasNewLines)
-{ 
-	int c; 
-	 
+{
+	int c;
+
 	while ((c = *data_p) <= ' ')
-	{ 
-		if (!c) 
-			return NULL; 
-		 
+	{
+		if (!c)
+			return NULL;
+
 		if (c == '\n')
-		{ 
-			com_parseLine++; 
-			*hasNewLines = true; 
-		} 
-		data_p++; 
-	} 
-	return data_p; 
+		{
+			com_parseLine++;
+			*hasNewLines = true;
+		}
+		data_p++;
+	}
+	return data_p;
 }
 void Com_SkipRestOfLine (char **data_p)
-{ 
-	char*data; 
-	int c; 
-	 
-	data = *data_p; 
+{
+	char*data;
+	int c;
+
+	data = *data_p;
 	while ((c = *data++) != 0)
-	{ 
+	{
 		if (c == '\n')
-		{ 
-			com_parseLine++; 
-			break; 
-		} 
-	} 
-	 
-	*data_p = data; 
+		{
+			com_parseLine++;
+			break;
+		}
+	}
+
+	*data_p = data;
 }
 char *Com_ParseExt (char **data_p, qboolean allowNewLines)
-{ 
-	int c, len = 0; 
-	char *data; 
-	qboolean hasNewLines = false; 
-	 
-	data = *data_p; 
-	com_token[0] = 0; 
-	 
-	// Make sure incoming data is valid 
+{
+	int c, len = 0;
+	char *data;
+	qboolean hasNewLines = false;
+
+	data = *data_p;
+	com_token[0] = 0;
+
+	// Make sure incoming data is valid
 	if (!data)
-	{ 
-		*data_p = NULL; 
-		return com_token; 
-	} 
-	 
-	// Backup the session data so we can unget easily 
-//	Com_BackupParseSession(data_p); 
-	 
+	{
+		*data_p = NULL;
+		return com_token;
+	}
+
+	// Backup the session data so we can unget easily
+//	Com_BackupParseSession(data_p);
+
 	while (1)
-	{ 
-		// Skip whitespace 
-		data = Com_SkipWhiteSpace(data, &hasNewLines); 
+	{
+		// Skip whitespace
+		data = Com_SkipWhiteSpace(data, &hasNewLines);
 		if (!data)
-		{ 
-			*data_p = NULL; 
-			return com_token; 
-		} 
-		 
+		{
+			*data_p = NULL;
+			return com_token;
+		}
+
 		if (hasNewLines && !allowNewLines)
-		{ 
-			*data_p = data; 
-			return com_token; 
-		} 
-		 
-		c = *data; 
-		 
-		// Skip // comments 
+		{
+			*data_p = data;
+			return com_token;
+		}
+
+		c = *data;
+
+		// Skip // comments
 		if (c == '/' && data[1] == '/')
-		{ 
-			while (*data && *data != '\n') 
-			data++; 
-		} 
-		 
-		// Skip /* */ comments 
+		{
+			while (*data && *data != '\n')
+			data++;
+		}
+
+		// Skip /* */ comments
 		else if (c == '/' && data[1] == '*')
-		{ 
-			data += 2; 
-			 
+		{
+			data += 2;
+
 			while (*data && (*data != '*' || data[1] != '/'))
-			{ 
-				if (*data == '\n') 
-					com_parseLine++; 
-			 
-				data++; 
-			} 
-		 
-			if (*data) 
-			data += 2; 
-		} 
-			 
-			// An actual token 
-			else 
-			break; 
-	} 
-	 
-	// Handle quoted strings specially 
+			{
+				if (*data == '\n')
+					com_parseLine++;
+
+				data++;
+			}
+
+			if (*data)
+			data += 2;
+		}
+
+			// An actual token
+			else
+			break;
+	}
+
+	// Handle quoted strings specially
 	if (c == '\"')
-	{ 
-		data++; 
+	{
+		data++;
 		while (1)
-		{ 
-			c = *data++; 
-			if (c == '\n') 
-				com_parseLine++; 
-			 
+		{
+			c = *data++;
+			if (c == '\n')
+				com_parseLine++;
+
 			if (c == '\"' || !c)
-			{ 
-				*data_p = data; 
-				com_token[len] = 0; 
-				return com_token; 
-			} 
-			if (len < MAX_TOKEN_CHARS) 
-			com_token[len++] = c; 
-		} 
-	} 
-	 
-	// Parse a regular word 
-	do 
-	{ 
-		if (len < MAX_TOKEN_CHARS) 
-			com_token[len++] = c; 
-		 
-		data++; 
-		c = *data; 
-	} while (c > 32); 
-	 
-	if (len == MAX_TOKEN_CHARS) 
-		len = 0; 
-	 
-	com_token[len] = 0; 
-	 
-	*data_p = data; 
-	return com_token; 
+			{
+				*data_p = data;
+				com_token[len] = 0;
+				return com_token;
+			}
+			if (len < MAX_TOKEN_CHARS)
+			com_token[len++] = c;
+		}
+	}
+
+	// Parse a regular word
+	do
+	{
+		if (len < MAX_TOKEN_CHARS)
+			com_token[len++] = c;
+
+		data++;
+		c = *data;
+	} while (c > 32);
+
+	if (len == MAX_TOKEN_CHARS)
+		len = 0;
+
+	com_token[len] = 0;
+
+	*data_p = data;
+	return com_token;
 }
 
 /*
@@ -1511,21 +1549,11 @@ void Com_PageInMemory (byte *buffer, int size)
 ============================================================================
 */
 
-// FIXME: replace all Q_stricmp with Q_strcasecmp
-int Q_stricmp (char *s1, char *s2)
-{
-#if defined(WIN32)
-	return _stricmp (s1, s2);
-#else
-	return strcasecmp (s1, s2);
-#endif
-}
 
-
-int Q_strncasecmp (char *s1, char *s2, int n)
+int Q_strncasecmp (const char *s1, const char *s2, int n)
 {
 	int		c1, c2;
-	
+
 	do
 	{
 		c1 = *s1++;
@@ -1533,7 +1561,7 @@ int Q_strncasecmp (char *s1, char *s2, int n)
 
 		if (!n--)
 			return 0;		// strings are equal until end point
-		
+
 		if (c1 != c2)
 		{
 			if (c1 >= 'a' && c1 <= 'z')
@@ -1544,11 +1572,11 @@ int Q_strncasecmp (char *s1, char *s2, int n)
 				return -1;		// strings not equal
 		}
 	} while (c1);
-	
+
 	return 0;		// strings are equal
 }
 
-int Q_strcasecmp (char *s1, char *s2)
+int Q_strcasecmp (const char *s1, const char *s2)
 {
 	return Q_strncasecmp (s1, s2, 99999);
 }
@@ -1564,9 +1592,9 @@ void Com_sprintf (char *dest, int size, char *fmt, ...)
 	va_start (argptr,fmt);
 	len = vsnprintf (bigbuffer,sizeof(bigbuffer), fmt,argptr);
 	va_end (argptr);
-	if (len >= size) 
+	if (len >= size)
 		Com_Printf ("Com_sprintf: overflow of %i in %i\n", len, size);
-		
+
 	//JD - Fix for potential server crashes.
 	bigbuffer[size-1] = '\0';
 	//strcpy (dest, bigbuffer);
@@ -1581,6 +1609,7 @@ void Com_sprintf (char *dest, int size, char *fmt, ...)
 ============================================================================
 */
 
+// not used, may be obsolete (2010-08)
 /*
 ==============
 Q_strncpyz
@@ -1604,6 +1633,8 @@ void Q_strncpyz( char *dest, const char *src, size_t size )
 Q_strncatz
 ==============
 */
+
+/*
 void Q_strncatz( char *dest, const char *src, size_t size )
 {
 #ifdef HAVE_STRLCAT
@@ -1619,6 +1650,7 @@ void Q_strncatz( char *dest, const char *src, size_t size )
 	}
 #endif
 }
+*/
 
 /*
 ==============
@@ -1656,13 +1688,16 @@ key and returns the associated value, or an empty string.
 */
 char *Info_ValueForKey (char *s, char *key)
 {
+	/*
+	 * 2010-11 Increase static buffers from 2 to 8 to avoid collisions
+	 *  Like g_utils.c::tv(),vtos()
+	 */
 	char	pkey[512];
-	static	char value[2][512];	// use two buffers so compares
-								// work without stomping on each other
-	static	int	valueindex;
+	static	char value[8][512];
+	static	int	valueindex = 0;
 	char	*o;
-	
-	valueindex ^= 1;
+
+	valueindex = (valueindex + 1) & 0x07;
 	if (*s == '\\')
 		s++;
 	while (1)
@@ -1735,7 +1770,13 @@ void Info_RemoveKey (char *s, char *key)
 
 		if (!strcmp (key, pkey) )
 		{
-			strcpy (start, s);	// remove this part
+			/* Two strcpy's instead of one - this was messing up
+			 * on modern, 64-bit Linux system due to "s" being modified
+			 * while it is being copied.
+			 * - E.B.
+			 */
+			strcpy( value , s );
+			strcpy( start , value );
 			return;
 		}
 
@@ -1820,7 +1861,7 @@ qboolean Info_KeyExists (const char *s, const char *key)
 {
 	char	pkey[512];
 	char	*o;
-	
+
 	if (*s == '\\')
 		s++;
 
@@ -1849,4 +1890,72 @@ qboolean Info_KeyExists (const char *s, const char *key)
 }
 //====================================================================
 
+/*
+ * ValidatePlayerName()
+ *
+ * checks validity of a player name string.
+ * may modify the string:
+ *   - player_name must NOT be const.
+ *   - player_name_size passes size of caller's char array
+ *
+ * returns: the number of glyphs (visible chars) in the player's name
+ */
+size_t ValidatePlayerName( char *player_name, size_t player_name_size )
+{
+	char *pch;
+	size_t count;
+	size_t char_count;
+	size_t glyph_count;
+	size_t char_count_limit;
 
+	assert( player_name != NULL );
+	assert( player_name_size > 0);
+	assert( strlen( player_name ) < 127 );
+
+	for ( pch = player_name, count = strlen( player_name); count--; pch++ )
+	{ // translate bad chars to space
+		if ( !isascii( *pch ) || !isgraph( *pch ) )
+			*pch = ' ';
+	}
+
+	if ( player_name_size < PLAYERNAME_SIZE )
+	{
+		char_count_limit = player_name_size - 1;
+	}
+	else
+	{
+		char_count_limit = PLAYERNAME_SIZE - 1;
+	}
+	char_count = glyph_count = 0;
+	pch = player_name;
+	while ( *pch
+			&& glyph_count < PLAYERNAME_GLYPHS
+			&& char_count < char_count_limit
+			)
+	{ // while chars and 1+ glyphs possible and 1+ chars possible.
+		if ( Q_IsColorString( pch ) )
+		{
+			if ( char_count < (char_count_limit-4) )
+			{ // room for 3 chars is available
+				char_count += 2;
+				pch += 2;
+			}
+			else
+			{ // no room for color escape and glyph, done
+				break;
+			}
+		}
+		else
+		{
+			++char_count;
+			++glyph_count;
+			++pch;
+		}
+	}
+	assert( char_count <= char_count_limit );
+	assert( glyph_count <= PLAYERNAME_GLYPHS );
+
+	player_name[ char_count ] = '\0'; // possible truncation
+
+	return glyph_count;
+}
