@@ -185,6 +185,7 @@ void VectorMA (vec3_t veca, float scale, vec3_t vecb, vec3_t vecc);
 #define Vector4Add(a,b,c)		((c)[0]=(((a[0])+(b[0]))),(c)[1]=(((a[1])+(b[1]))),(c)[2]=(((a[2])+(b[2]))),(c)[3]=(((a[3])+(b[3]))))
 #define Vector4Sub(a,b,c)		((c)[0]=(((a[0])-(b[0]))),(c)[1]=(((a[1])-(b[1]))),(c)[2]=(((a[2])-(b[2]))),(c)[3]=(((a[3])-(b[3]))))
 #define Vector4Avg(a,b,c)		((c)[0]=(((a[0])+(b[0]))*0.5f),(c)[1]=(((a[1])+(b[1]))*0.5f),(c)[2]=(((a[2])+(b[2]))*0.5f),(c)[3]=(((a[3])+(b[3]))*0.5f))
+#define Vector4Clear(a)			((a)[0]=(a)[1]=(a)[2]=(a)[3]=0)
 
 #define DEG2RAD( a ) (( (a) * M_PI ) / 180.0F)
 #define RAD2DEG( a ) (( (a) * 180.0F ) / M_PI)
@@ -212,6 +213,7 @@ void R_ConcatTransforms (float in1[3][4], float in2[3][4], float out[3][4]);
 void NormalToLatLong( const vec3_t normal, byte latlong[2] );
 void LatLongToNormal( byte latlong[2], vec3_t normal );
 
+void fast_sincosf( float angle, float *sina, float *cosa );
 void AngleVectors (vec3_t angles, vec3_t forward, vec3_t right, vec3_t up);
 void vectoangles (vec3_t value1, vec3_t angles);
 int BoxOnPlaneSide (vec3_t emins, vec3_t emaxs, struct cplane_s *plane);
@@ -360,7 +362,10 @@ CVARS (console variables)
 #define	CVAR_NOSET		8	// don't allow change from console at all,
 							// but can be set from the command line
 #define	CVAR_LATCH		16	// save changes until server restart
-#define CVAR_ROM		32 //cannot be set by user at all
+#define CVAR_ROM		32  // cannot be set by user at all
+#define CVAR_GAMEINFO   64  // added to the 'mods' field of the serverinfo
+                            // string when changed
+#define CVAR_PROFILE	128 // profile information
 
 // nothing outside the Cvar_*() functions should modify these fields!
 typedef struct cvar_s
@@ -372,6 +377,7 @@ typedef struct cvar_s
 	int		flags;
 	qboolean	modified;		// set each time the cvar is changed
 	float		value;
+	float		default_value;
 	int		integer;		//BLOOMS
 	struct cvar_s	*next;
 } cvar_t;
@@ -804,7 +810,6 @@ typedef struct
 #define DF_ALLOW_EXIT		0x00001000	// 4096
 #define DF_INFINITE_AMMO	0x00002000	// 8192
 #define DF_QUAD_DROP		0x00004000	// 16384
-#define DF_FIXED_FOV		0x00008000	// 32768
 
 // RAFAEL
 #define	DF_QUADFIRE_DROP	0x00010000	// 65536
