@@ -219,8 +219,10 @@ PROTOCOL
 
 #define	PORT_MASTER	27900
 #define	PORT_CLIENT	27901
+#define PORT_STATS	27902
 #define	PORT_SERVER	27910
 
+
 //=========================================
 
 #define	UPDATE_BACKUP	16	// copies of entity_state_t to keep buffered
@@ -663,6 +665,7 @@ CMODEL
 #include "qcommon/qfiles.h"
 
 cmodel_t	*CM_LoadMap (char *name, qboolean clientload, unsigned *checksum);
+cmodel_t	*CM_LoadBSP (char *name, qboolean clientload, unsigned *checksum);
 cmodel_t	*CM_InlineModel (char *name);	// *1, *2, etc
 
 int			CM_NumClusters (void);
@@ -708,6 +711,8 @@ qboolean	CM_HeadnodeVisible (int headnode, byte *visbits);
 void		CM_WritePortalState (FILE *f);
 void		CM_ReadPortalState (FILE *f);
 
+extern char map_name[MAX_QPATH];
+
 /*
 ==============================================================
 
