@@ -89,6 +89,7 @@ extern	entity_t	*currententity;
 extern	model_t		*currentmodel;
 extern	int			r_visframecount;
 extern	int			r_framecount;
+extern  int			r_shadowmapcount;	
 extern	cplane_t	frustum[4];
 extern	int			c_brush_polys, c_alias_polys;
 extern 	int c_flares;
@@ -179,6 +180,7 @@ extern  cvar_t  *r_ragdoll_debug;
 extern	qboolean	map_fog;
 extern	char		map_music[128];
 extern  unsigned	r_weather;
+extern unsigned		r_nosun;
 
 extern  cvar_t		*r_minimap;
 extern  cvar_t		*r_minimap_size;
@@ -287,11 +289,16 @@ void R_FB_InitTextures(void);
 //VBO
 extern GLuint vboId;
 extern int totalVBOsize;
+extern int	vboPosition;
 extern void R_LoadVBOSubsystem(void);
 extern void R_VCShutdown(void);
 extern void VB_VCInit(void);
 extern void VB_BuildVBOBufferSize(msurface_t *surf);
 extern void VB_BuildWorldVBO(void);
+void GL_BindVBO(vertCache_t *cache);
+void GL_BindIBO(vertCache_t *cache);
+vertCache_t *R_VCFindCache(vertStoreMode_t store, entity_t *ent);
+vertCache_t *R_VCLoadData(vertCacheMode_t mode, int size, void *buffer, vertStoreMode_t store, entity_t *ent);
 
 //Light Bloom
 extern void R_BloomBlend( refdef_t *fd );
@@ -318,6 +325,7 @@ extern void R_RenderSun();
 int r_numgrasses;
 extern int c_grasses;
 grass_t r_grasses[MAX_GRASSES];
+qboolean r_hasleaves;
 extern void Mod_AddVegetationSurface (msurface_t *surf, int texnum, vec3_t color, float size, char name[MAX_QPATH], int type);
 extern void R_DrawVegetationSurface (void);
 extern void R_ClearGrasses(void);
@@ -487,6 +495,8 @@ extern int KillFlags;
 
 extern float	tex_array[MAX_ARRAY][2];
 extern float	vert_array[MAX_ARRAY][3];
+extern float	norm_array[MAX_ARRAY][3];
+extern float	tan_array[MAX_ARRAY][4];
 extern float	col_array[MAX_ARRAY][4];
 
 #define MAX_VARRAY_VERTS (MAX_VERTS + 2)
@@ -534,6 +544,7 @@ extern vec3_t ShadowArray[MAX_SHADOW_VERTS];
 // vertex array subsystem
 extern void R_InitVArrays (int varraytype);
 extern void R_KillVArrays (void);
+extern void R_DrawVarrays(GLenum mode, GLint first, GLsizei count, qboolean vbo);
 extern void R_InitQuadVarrays(void);
 extern void R_AddSurfToVArray (msurface_t *surf);
 extern void R_AddTexturedSurfToVArray (msurface_t *surf, float scroll);
@@ -545,10 +556,11 @@ extern void R_KillNormalTMUs(void);
 extern	cvar_t		*r_shadowmapratio;
 extern  int			r_lightgroups;
 extern  image_t		*r_depthtexture;
+extern	image_t		*r_depthtexture2;
 extern  image_t		*r_colorbuffer;
 extern  image_t		*r_shadowbuffer;
 extern	image_t		*r_shadowbufferBlur;
-extern GLuint   fboId[2];
+extern GLuint   fboId[3];
 extern GLuint	rboId;
 extern vec3_t	r_worldLightVec;
 extern qboolean have_stencil;
@@ -566,6 +578,7 @@ extern void		MD2_DrawCaster (void);
 extern void		IQM_DrawCaster (void);
 extern void		IQM_DrawRagDollCaster (int);
 extern void		R_DrawDynamicCaster(void);
+extern void		R_DrawVegetationCaster(void);
 extern void		R_CastShadow(void);
 extern float	SHD_ShadowLight (vec3_t pos, vec3_t angles, vec3_t lightAdd, int type);
 int				FB_texture_width, FB_texture_height;
@@ -596,11 +609,13 @@ extern GLuint		g_location_heightTexture;
 extern GLuint		g_location_lmTexture;
 extern GLuint		g_location_normalTexture;
 extern GLuint		g_location_bspShadowmapTexture;
+extern GLuint		g_location_bspShadowmapTexture2;
 extern GLuint		g_location_bspShadowmapNum;
 extern GLuint		g_location_fog;
 extern GLuint		g_location_parallax;
 extern GLuint		g_location_dynamic;
 extern GLuint		g_location_shadowmap;
+extern GLuint		g_Location_statshadow;
 extern GLuint		g_location_lightPosition;
 extern GLuint		g_location_staticLightPosition;
 extern GLuint		g_location_lightColour;
