@@ -28,6 +28,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "r_ragdoll.h"
 #include "r_text.h"
 
+
 void R_Clear (void);
 
 viddef_t	vid;
@@ -187,6 +188,9 @@ cvar_t	*r_firstrun;
 //for testing
 cvar_t  *r_test;
 
+//ODE initialization error check
+int r_odeinit_success; // 0 if dODEInit2() fails, 1 otherwise.
+
 //fog stuff
 struct r_fog
 {
@@ -198,6 +202,7 @@ struct r_fog
 	float density;
 } fog;
 unsigned r_weather;
+unsigned r_nosun;
 
 /*
 =================
@@ -244,6 +249,8 @@ void R_ReadFogScript( char *config_file )
 			fog.density = atof(a_string);
 			strcpy( a_string, COM_Parse( &s ) );
 			r_weather = atoi(a_string);
+			strcpy( a_string, COM_Parse( &s ) );
+			r_nosun = atoi(a_string);
 
 			if(fog.density > 0)
 				map_fog = true;
@@ -428,6 +435,30 @@ void R_DrawNullModel (void)
 	qglEnable (GL_TEXTURE_2D);
 }
 
+/*
+=============
+LOD calculation
+
+The width and height occupied by a model on screen after it's been rendered
+will scale as the square of the FOV setting, and proportionally to the
+width/height of the screen itself. Based on the assumption that 500 units is
+an adequate LOD cutoff distance at 1920*1080 with an FOV of 90, we can scale
+the LOD cutoff distance to the lowest point where there will be no noticable
+ugliness.
+
+NOTE: Turns out the player's FOV setting goes to fov_x and not fov_y. Go
+figure.
+=============
+*/
+#define LOD_BASE_H      1920.0
+#define LOD_BASE_W      1080.0
+#define LOD_BASE_DIST   500.0
+#define LOD_BASE_FOV    90.0
+#define LOD_DIST        (LOD_BASE_DIST*\
+                        (vid.width/LOD_BASE_W)*(vid.height/LOD_BASE_H)*\
+                        (LOD_BASE_FOV/r_newrefdef.fov_x)*\
+                        (LOD_BASE_FOV/r_newrefdef.fov_x))
+
 /*
 =============
 R_DrawEntitiesOnList
@@ -443,6 +474,11 @@ void R_DrawEntitiesOnList (void)
 	if (!r_drawentities->value)
 		return;
 
+	if ( !r_odeinit_success )
+	{ // ODE init failed, force ragdolls off
+		r_ragdolls = Cvar_ForceSet("r_ragdolls", "0");
+	}
+
 	// draw non-transparent first
 	for (i=0 ; i<r_newrefdef.num_entities ; i++)
 	{
@@ -472,19 +508,16 @@ void R_DrawEntitiesOnList (void)
 		currentmodel = currententity->model;
 
 		//get distance, set lod if available
-		if(r_newrefdef.fov_y >= 90)
+		VectorSubtract(r_origin, currententity->origin, dist);
+		if(VectorLength(dist) > LOD_DIST*2.0)
 		{
-			VectorSubtract(r_origin, currententity->origin, dist);
-			if(VectorLength(dist) > 1000)
-			{
-				if(currententity->lod2)
-					currentmodel = currententity->lod2;
-			}
-			else if(VectorLength(dist) > 500)
-			{
-				if(currententity->lod1)
-					currentmodel = currententity->lod1;
-			}
+			if(currententity->lod2)
+				currentmodel = currententity->lod2;
+		}
+		else if(VectorLength(dist) > LOD_DIST)
+		{
+			if(currententity->lod1)
+				currentmodel = currententity->lod1;
 		}
 
 		if (!currentmodel)
@@ -537,7 +570,6 @@ void R_DrawEntitiesOnList (void)
 				currententity->script = NULL;
 		}
 
-
 		currentmodel = currententity->model;
 
 		if (!currentmodel)
@@ -562,7 +594,6 @@ void R_DrawEntitiesOnList (void)
 		}
 	}
 	qglDepthMask (1);		// back to writing
-
 }
 
 void R_DrawViewEntitiesOnList (void)
@@ -603,7 +634,6 @@ void R_DrawViewEntitiesOnList (void)
 				currententity->script = NULL;
 		}
 
-
 		currentmodel = currententity->model;
 
 		if (!currentmodel)
@@ -916,11 +946,16 @@ void R_SetupGL (void)
 R_Clear
 =============
 */
+extern cvar_t *info_spectator;
+extern cvar_t *cl_add_blend;
 extern qboolean have_stencil;
 void R_Clear (void)
 {
+	qglClearColor(0,0,0,1);
 	if (gl_clear->value)
 		qglClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+	else if (!cl_add_blend->value && info_spectator->value && (CM_PointContents(r_newrefdef.vieworg, 0) & CONTENTS_SOLID))
+		qglClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT); //out of map
 	else
 		qglClear (GL_DEPTH_BUFFER_BIT);
 
@@ -979,6 +1014,8 @@ void R_RenderView (refdef_t *fd)
 
 		R_DrawDynamicCaster();
 
+		R_DrawVegetationCaster();
+
 		qglBindFramebufferEXT(GL_FRAMEBUFFER_EXT,0);
 
 		//Enabling color write (previously disabled for light POV z-buffer rendering)
@@ -1027,14 +1064,14 @@ void R_RenderView (refdef_t *fd)
 	if(r_lensflare->value)
 		R_RenderFlares ();
 
-	R_DrawVegetationSurface ();
-
 	R_DrawEntitiesOnList ();
+		
+	R_DrawVegetationSurface ();
 
 	R_CastShadow();
 
 	R_RenderAllRagdolls(); //move back ahead of r_castshadow when we figure out shadow jitter bug
-
+	
 	R_DrawViewEntitiesOnList ();
 
 	R_DrawAlphaSurfaces ();
@@ -1054,7 +1091,7 @@ void R_RenderView (refdef_t *fd)
 
 	R_BloomBlend( fd );//BLOOMS
 
-	R_RenderSun();	
+	R_RenderSun();
 
 	R_GLSLPostProcess();
 
@@ -1081,7 +1118,7 @@ void R_RenderView (refdef_t *fd)
 
 	if(map_fog)
 		qglDisable(GL_FOG);
-	
+
 	R_DrawRadar();
 }
 
@@ -1201,7 +1238,7 @@ void R_Register( void )
 
 	r_overbrightbits = Cvar_Get( "r_overbrightbits", "2", CVAR_ARCHIVE );
 
-	gl_usevbo = Cvar_Get("gl_usevbo", "0", CVAR_ARCHIVE );
+	gl_usevbo = Cvar_Get("gl_usevbo", "1", CVAR_ARCHIVE );
 
 	gl_mirror = Cvar_Get("gl_mirror", "1", CVAR_ARCHIVE);
 
@@ -1226,7 +1263,6 @@ void R_Register( void )
 	r_minimap_zoom = Cvar_Get ("r_minimap_zoom", "1", CVAR_ARCHIVE );
 	r_minimap_style = Cvar_Get ("r_minimap_style", "1", CVAR_ARCHIVE );
 	r_minimap = Cvar_Get ("r_minimap", "0", CVAR_ARCHIVE );
-
 	r_ragdolls = Cvar_Get ("r_ragdolls", "1", CVAR_ARCHIVE );
 	r_ragdoll_debug = Cvar_Get("r_ragdoll_debug", "0", CVAR_ARCHIVE );
 
@@ -1238,7 +1274,7 @@ void R_Register( void )
 
 	r_firstrun = Cvar_Get("r_firstrun", "0", CVAR_ARCHIVE); //first time running the game
 
-	r_test = Cvar_Get("r_test", "1", CVAR_ARCHIVE); //for testing things
+	r_test = Cvar_Get("r_test", "0", CVAR_ARCHIVE); //for testing things
 
 	Cmd_AddCommand( "imagelist", GL_ImageList_f );
 	Cmd_AddCommand( "screenshot", GL_ScreenShot_f );
@@ -1578,8 +1614,8 @@ int R_Init( void *hinstance, void *hWnd )
 		Com_Printf ("...GL_EXT_point_parameters not found\n" );
 	}
 
-	R_InitImageSubsystem();	
-	
+	R_InitImageSubsystem();
+
 	R_InitShadowSubsystem();
 
 	R_LoadVBOSubsystem();
@@ -1698,9 +1734,19 @@ cpuinfo_exit:
 	VLight_Init();
 
 	//Initialize ODE
-	dInitODE2(0);
+	// ODE assert failures sometimes occur, this may or may not help.
+	r_odeinit_success = dInitODE2(0);
 	//ODE - clear out any ragdolls;
-	R_ClearAllRagdolls();
+	if ( r_odeinit_success )
+	{
+		Com_Printf("...ODE initialized.\n");
+		R_ClearAllRagdolls();
+		Com_Printf("...Ragdolls initialized.\n");
+	}
+	else
+	{
+		Com_Printf("...ODE initialization failed.\n...Ragdolls are disabled.\n");
+	}
 
 	scr_playericonalpha = 0.0;
 
@@ -1747,7 +1793,12 @@ void R_Shutdown (void)
 	QGL_Shutdown();
 
 	//Shutdown ODE
-	dCloseODE();
+	// ODE might fail assert on close when not intialized
+	if ( r_odeinit_success )
+	{
+		Com_DPrintf("Closing ODE\n");
+		dCloseODE();
+	}
 }
 
 
