@@ -42,7 +42,8 @@ float	r_avertexnormals[NUMVERTEXNORMALS][3] = {
 
 static  vec4_t  s_lerped[MAX_VERTS];
 
-// static	vec3_t	s_normals[MAX_VERTS]; // unused
+static vec3_t VertexArray[MAX_VERTICES];
+static vec2_t TexCoordArray[MAX_VERTICES];
 static vec3_t NormalsArray[MAX_VERTICES];
 static vec4_t TangentsArray[MAX_VERTICES];
 
@@ -675,6 +676,8 @@ void Mod_LoadMD2Model (model_t *mod, void *buffer)
 		}
 	}
 
+	mod->num_triangles = pheader->num_tris;
+
 	paliashdr = (dmdl_t *)mod->extradata;
 
 	//redo this using max/min from all frames
@@ -713,7 +716,7 @@ void Mod_LoadMD2Model (model_t *mod, void *buffer)
 			tmp[2] = mod->maxs[2];
 
 		VectorCopy( tmp, mod->bbox[i] );
-	}
+	}	
 }
 
 //==============================================================
@@ -1254,15 +1257,9 @@ void MD2_DrawFrame (dmdl_t *paliashdr, float backlerp, qboolean lerped, int skin
             }
         }
 
-		if (!(!cl_gun->value && ( currententity->flags & RF_WEAPONMODEL ) ) ) {
-
-				if(qglLockArraysEXT)
-					qglLockArraysEXT(0, va);
-
-				qglDrawArrays(GL_TRIANGLES,0,va);
-
-				if(qglUnlockArraysEXT)
-					qglUnlockArraysEXT();
+		if (!(!cl_gun->value && ( currententity->flags & RF_WEAPONMODEL ) ) ) 
+		{
+			R_DrawVarrays(GL_TRIANGLES, 0, va, false);
 		}
 
 		if(gl_glsl_shaders->value && gl_state.glsl_shaders && gl_normalmaps->value) {
@@ -1324,15 +1321,8 @@ void MD2_DrawFrame (dmdl_t *paliashdr, float backlerp, qboolean lerped, int skin
 		}
 		if (!(!cl_gun->value && ( currententity->flags & RF_WEAPONMODEL ) ) )
 		{
-				if(qglLockArraysEXT)
-					qglLockArraysEXT(0, va);
-
-				qglDrawArrays(GL_TRIANGLES,0,va);
-
-				if(qglUnlockArraysEXT)
-					qglUnlockArraysEXT();
+			R_DrawVarrays(GL_TRIANGLES, 0, va, false);
 		}
-
 	}
 	else if(rs)
 	{
@@ -1437,13 +1427,19 @@ void MD2_DrawFrame (dmdl_t *paliashdr, float backlerp, qboolean lerped, int skin
 
 			if(stage->normalmap)
 			{
-
 				vec3_t lightVec, lightVal;
 
-				R_InitVArrays (VERT_NORMAL_COLOURED_TEXTURED);
-				qglNormalPointer(GL_FLOAT, 0, NormalsArray);
-				glEnableVertexAttribArrayARB (1);
-				glVertexAttribPointerARB(1, 4, GL_FLOAT,GL_FALSE, 0, TangentsArray);
+				if(gl_state.vbo && !lerped)
+				{
+					KillFlags |= (KILL_TMU0_POINTER | KILL_TMU1_POINTER | KILL_TMU2_POINTER | KILL_NORMAL_POINTER);
+				}
+				else 
+				{
+					R_InitVArrays (VERT_NORMAL_COLOURED_TEXTURED);
+					qglNormalPointer(GL_FLOAT, 0, NormalsArray);
+					glEnableVertexAttribArrayARB (1);
+					glVertexAttribPointerARB(1, 4, GL_FLOAT, GL_FALSE, 0, TangentsArray);
+				}
 
 				R_GetLightVals(currententity->origin, false, true);
 
@@ -1530,7 +1526,29 @@ void MD2_DrawFrame (dmdl_t *paliashdr, float backlerp, qboolean lerped, int skin
 				glUniform1fARB( g_location_meshTime, rs_realtime);
 
 				glUniform1iARB( g_location_meshFog, map_fog);
-			}
+
+				if (gl_state.vbo && !lerped)
+				{
+					currentmodel->vbo_xyz = R_VCFindCache(VBO_STORE_XYZ, currententity);
+					if (currentmodel->vbo_xyz) 
+					{						
+						currentmodel->vbo_st = R_VCFindCache(VBO_STORE_ST, currententity);
+						if(currentmodel->vbo_st)
+						{
+							currentmodel->vbo_normals = R_VCFindCache(VBO_STORE_NORMAL, currententity);
+							if(currentmodel->vbo_normals)
+							{
+								currentmodel->vbo_tangents = R_VCFindCache(VBO_STORE_TANGENT, currententity);
+								if(currentmodel->vbo_tangents)
+								{
+									//Com_Printf("skipped\n");
+									goto skipLoad;
+								}
+							}
+						}
+					}
+				}
+			}			
 
 			for (i=0; i<paliashdr->num_tris; i++)
 			{
@@ -1671,6 +1689,15 @@ void MD2_DrawFrame (dmdl_t *paliashdr, float backlerp, qboolean lerped, int skin
 							VArray[8] = nAlpha;
 						}
 					}
+					else if(gl_state.vbo && !lerped) 
+					{
+						VertexArray[va][0] = VArray[0];
+						VertexArray[va][1] = VArray[1];
+						VertexArray[va][2] = VArray[2];
+
+						TexCoordArray[va][0] = VArray[3];
+						TexCoordArray[va][1] = VArray[4];
+					}
 
 					// increment pointer and counter
 					if(stage->normalmap)
@@ -1683,15 +1710,39 @@ void MD2_DrawFrame (dmdl_t *paliashdr, float backlerp, qboolean lerped, int skin
 				}
 			}
 
-			if (!(!cl_gun->value && ( currententity->flags & RF_WEAPONMODEL ) ) )
+			if(gl_state.vbo && !lerped && stage->normalmap)
 			{
-				if(qglLockArraysEXT)
-					qglLockArraysEXT(0, va);
+                currentmodel->vbo_xyz = R_VCLoadData(VBO_STATIC, va*sizeof(vec3_t), VertexArray, VBO_STORE_XYZ, currententity);
+				currentmodel->vbo_st = R_VCLoadData(VBO_STATIC, va*sizeof(vec2_t), TexCoordArray, VBO_STORE_ST, currententity);
+				currentmodel->vbo_normals = R_VCLoadData(VBO_STATIC, va*sizeof(vec3_t), NormalsArray, VBO_STORE_NORMAL, currententity);
+				currentmodel->vbo_tangents = R_VCLoadData(VBO_STATIC, va*sizeof(vec4_t), TangentsArray, VBO_STORE_TANGENT, currententity);
+				//Com_Printf("Loading mesh vbo.\n");
+            }
+skipLoad:
+			if(gl_state.vbo && !lerped && stage->normalmap) 
+			{
+				qglEnableClientState( GL_VERTEX_ARRAY );
+				GL_BindVBO(currentmodel->vbo_xyz);
+				qglVertexPointer(3, GL_FLOAT, 0, 0);
 
-				qglDrawArrays(GL_TRIANGLES,0,paliashdr->num_tris*3);
+				qglEnableClientState(GL_TEXTURE_COORD_ARRAY);
+				GL_BindVBO(currentmodel->vbo_st);
+				qglTexCoordPointer(2, GL_FLOAT, 0, 0);
 
-				if(qglUnlockArraysEXT)
-					qglUnlockArraysEXT();
+				qglEnableClientState( GL_NORMAL_ARRAY );
+				GL_BindVBO(currentmodel->vbo_normals);
+				qglNormalPointer(GL_FLOAT, 0, 0);
+
+				glEnableVertexAttribArrayARB (1);
+				GL_BindVBO(currentmodel->vbo_tangents);
+				glVertexAttribPointerARB(1, 4, GL_FLOAT, GL_FALSE, sizeof(vec4_t), 0);
+
+				if (!(!cl_gun->value && ( currententity->flags & RF_WEAPONMODEL )))
+					R_DrawVarrays(GL_TRIANGLES, 0, paliashdr->num_tris*3, true);
+	        }
+         	else if (!(!cl_gun->value && ( currententity->flags & RF_WEAPONMODEL )))
+			{
+				R_DrawVarrays(GL_TRIANGLES, 0, paliashdr->num_tris*3, false);
 			}
 
 			qglColor4f(1,1,1,1);
@@ -1702,7 +1753,6 @@ void MD2_DrawFrame (dmdl_t *paliashdr, float backlerp, qboolean lerped, int skin
 			if(stage->normalmap)
 			{
 				glUseProgramObjectARB( 0 );
-
 				GL_EnableMultitexture( false );
 			}
 
@@ -1720,8 +1770,9 @@ done:
 	qglDisableClientState( GL_NORMAL_ARRAY);
 	qglDisableClientState( GL_COLOR_ARRAY );
 	qglEnableClientState( GL_TEXTURE_COORD_ARRAY );
+	glDisableVertexAttribArrayARB (1);
 
-	R_KillVArrays ();
+	R_KillVArrays ();	
 
 	if ( currententity->flags & ( RF_SHELL_RED | RF_SHELL_GREEN | RF_SHELL_BLUE | RF_SHELL_DOUBLE | RF_SHELL_HALF_DAM ) )
 		qglEnable( GL_TEXTURE_2D );
@@ -1817,7 +1868,7 @@ void MD2_DrawShadow(dmdl_t *paliashdr, qboolean lerped)
 
 	}
 
-	qglDrawArrays(GL_TRIANGLES,0,va);
+	R_DrawVarrays(GL_TRIANGLES, 0, va, false);
 
 	qglDisableClientState( GL_COLOR_ARRAY );
 	qglEnableClientState( GL_TEXTURE_COORD_ARRAY );
@@ -2228,7 +2279,8 @@ void MD2_DrawCasterFrame (dmdl_t *paliashdr, float backlerp, qboolean lerped)
 
 	AngleVectors (currententity->angles, vectors[0], vectors[1], vectors[2]);
 
-	if(lerped) {
+	if(lerped) 
+	{
 		move[0] = DotProduct (delta, vectors[0]);	// forward
 		move[1] = -DotProduct (delta, vectors[1]);	// left
 		move[2] = DotProduct (delta, vectors[2]);	// up
@@ -2241,49 +2293,75 @@ void MD2_DrawCasterFrame (dmdl_t *paliashdr, float backlerp, qboolean lerped)
 			frontv[i] = frontlerp*frame->scale[i];
 			backv[i] = backlerp*oldframe->scale[i];
 		}
-
 	}
 
 	va=0;
 	VArray = &VArrayVerts[0];
 	R_InitVArrays (VERT_NO_TEXTURE);
 
-	for (i=0; i<paliashdr->num_tris; i++)
+	if (gl_state.vbo && !lerped)
 	{
-		for (j=0; j<3; j++)
+		currentmodel->vbo_xyz = R_VCFindCache(VBO_STORE_XYZ, currententity);
+		if (currentmodel->vbo_xyz) 
+		{
+			//Com_Printf("Skipped.\n");
+			goto skipLoad;
+		}
+	}
+
+	for (i = 0; i < paliashdr->num_tris; i++)
+	{
+		for (j = 0; j < 3; j++)
 		{
 			index_xyz = tris[i].index_xyz[j];
 			index_st = tris[i].index_st[j];
 
-			if(lerped) {
-
+			if(lerped) 
+			{
 				VArray[0] = s_lerped[index_xyz][0] = move[0] + ov[index_xyz].v[0]*backv[0] + v[index_xyz].v[0]*frontv[0];
 				VArray[1] = s_lerped[index_xyz][1] = move[1] + ov[index_xyz].v[1]*backv[1] + v[index_xyz].v[1]*frontv[1];
 				VArray[2] = s_lerped[index_xyz][2] = move[2] + ov[index_xyz].v[2]*backv[2] + v[index_xyz].v[2]*frontv[2];
 
 			}
-			else {
-
+			else 
+			{
 				VArray[0] = currentmodel->vertexes[index_xyz].position[0];
 				VArray[1] = currentmodel->vertexes[index_xyz].position[1];
 				VArray[2] = currentmodel->vertexes[index_xyz].position[2];
 
+				if(gl_state.vbo) 
+				{
+					VertexArray[va][0] = VArray[0];
+					VertexArray[va][1] = VArray[1];
+					VertexArray[va][2] = VArray[2];
+				}
 			}
 
 			// increment pointer and counter
 			VArray += VertexSizes[VERT_NO_TEXTURE];
 			va++;
 		}
-
 	}
 
-	if(qglLockArraysEXT)
-		qglLockArraysEXT(0, va);
+	if(gl_state.vbo && !lerped)
+	{
+		currentmodel->vbo_xyz = R_VCLoadData(VBO_STATIC, va*sizeof(vec3_t), VertexArray, VBO_STORE_XYZ, currententity);
+		//Com_Printf("Loading mesh vbo.\n");
+    }
 
-	qglDrawArrays(GL_TRIANGLES,0,va);
+skipLoad:
+	if(gl_state.vbo && !lerped) 
+	{
+		qglEnableClientState( GL_VERTEX_ARRAY );
+		GL_BindVBO(currentmodel->vbo_xyz);
+		qglVertexPointer(3, GL_FLOAT, 0, 0);   
 
-	if(qglUnlockArraysEXT)
-		qglUnlockArraysEXT();
+		R_DrawVarrays(GL_TRIANGLES, 0, paliashdr->num_tris*3, true);
+    }
+	else
+	{    
+		R_DrawVarrays(GL_TRIANGLES, 0, paliashdr->num_tris*3, false);
+	}
 
 	R_KillVArrays ();
 }
