@@ -46,14 +46,10 @@ model_t	mod_inline[MAX_MOD_KNOWN];
 LightGroup_t LightGroups[MAX_LIGHTS];
 int r_lightgroups;
 
-static float	r_avertexnormals[NUMVERTEXNORMALS][3] = {
-#include "anorms.h"
-};
 
 int		registration_sequence;
 
 char map_music[128];
-extern unsigned r_weather;
 
 char		map_entitystring[MAX_MAP_ENTSTRING];
 int			numentitychars;
@@ -144,7 +140,7 @@ void R_RegisterLightGroups (void)
 
 /*
 ================
-R_ParseLightEntities - BERSERK
+R_ParseLightEntities
 
 parses light entity string
 ================
@@ -238,6 +234,155 @@ static void R_ParseLightEntities (void)
 	}
 }
 
+static void R_FindSunTarget (void)
+{
+
+	int			i;
+	char		*entString;
+	char		*buf, *tok;
+	char		block[2048], *bl;
+	
+	entString = map_entitystring;
+
+	buf = CM_EntityString();
+	while (1){
+		tok = Com_ParseExt(&buf, true);
+		if (!tok[0])
+			break;			// End of data
+
+		if (Q_strcasecmp(tok, "{"))
+			continue;		// Should never happen!
+
+		// Parse the text inside brackets
+		block[0] = 0;
+		do {
+			tok = Com_ParseExt(&buf, false);
+			if (!Q_strcasecmp(tok, "}"))
+				break;		// Done
+
+			if (!tok[0])	// Newline
+				Q_strcat(block, "\n", sizeof(block));
+			else {			// Token
+				Q_strcat(block, " ", sizeof(block));
+				Q_strcat(block, tok, sizeof(block));
+			}
+		} while (buf);
+
+		// Now look for "targetname"
+		tok = strstr(block, "targetname");
+		if (!tok)
+			continue;		// Not found
+
+		// Skip over "target" and whitespace
+		tok += strlen("targetname");
+		while (*tok && *tok == ' ')
+			tok++;
+
+		// Next token must match the sun targetname
+		if (Q_strnicmp(tok, "moonspot", 8) && Q_strnicmp(tok, "sunspot", 7))
+			continue;
+	
+		// Finally parse the sun target entity
+		bl = block;
+		while (1){
+			tok = Com_ParseExt(&bl, true);
+			if (!tok[0])
+				break;		// End of data
+
+			if (!Q_strcasecmp("origin", tok)){
+				for (i = 0; i < 3; i++){
+					tok = Com_ParseExt(&bl, false);
+					r_sunLight->target[i] = atof(tok);
+				}
+				//Com_Printf("Found sun target@ : %4.2f %4.2f %4.2f\n", r_sunLight->target[0], r_sunLight->target[1], r_sunLight->target[2]);
+			}
+			else
+				Com_SkipRestOfLine(&bl);
+		}
+	}
+}
+
+static void R_FindSunEntity (void)
+{
+
+	int			i;
+	char		*entString;
+	char		*buf, *tok;
+	char		block[2048], *bl;
+
+	if(r_sunLight)
+		free(r_sunLight); //free at level load
+
+	r_sunLight = (sunLight_t*)malloc(sizeof(sunLight_t));
+
+	r_sunLight->has_Sun = false;
+
+	entString = map_entitystring;
+
+	buf = CM_EntityString();
+	while (1){
+		tok = Com_ParseExt(&buf, true);
+		if (!tok[0])
+			break;			// End of data
+
+		if (Q_strcasecmp(tok, "{"))
+			continue;		// Should never happen!
+
+		// Parse the text inside brackets
+		block[0] = 0;
+		do {
+			tok = Com_ParseExt(&buf, false);
+			if (!Q_strcasecmp(tok, "}"))
+				break;		// Done
+
+			if (!tok[0])	// Newline
+				Q_strcat(block, "\n", sizeof(block));
+			else {			// Token
+				Q_strcat(block, " ", sizeof(block));
+				Q_strcat(block, tok, sizeof(block));
+			}
+		} while (buf);
+
+		// Now look for "target"
+		tok = strstr(block, "target");
+		if (!tok)
+			continue;		// Not found
+
+		// Skip over "target" and whitespace
+		tok += strlen("target");
+		while (*tok && *tok == ' ')
+			tok++;
+
+		// Next token must be a valid sun name( to do - maybe read this from the map header if possible?)
+		if (Q_strnicmp(tok, "moonspot", 8) && Q_strnicmp(tok, "sunspot", 7))
+			continue;
+
+		strcpy(r_sunLight->targetname, tok);
+	
+		// Finally parse the sun entity
+		bl = block;
+		while (1){
+			tok = Com_ParseExt(&bl, true);
+			if (!tok[0])
+				break;		// End of data
+
+			if (!Q_strcasecmp("origin", tok)){
+				for (i = 0; i < 3; i++){
+					tok = Com_ParseExt(&bl, false);
+					r_sunLight->origin[i] = atof(tok);
+					r_sunLight->target[i] = 0; //default to this
+				}
+				r_sunLight->has_Sun = true;
+				//Com_Printf("Found sun @ : %4.2f %4.2f %4.2f\n", r_sunLight->origin[0], r_sunLight->origin[1], r_sunLight->origin[2]);
+			}
+			else
+				Com_SkipRestOfLine(&bl);
+		}
+	}
+	if(r_sunLight->has_Sun)
+		R_FindSunTarget(); //find target
+}
+
 /*
 ===============
 Mod_PointInLeaf
@@ -732,11 +877,18 @@ void Mod_LoadTexinfo (lump_t *l)
 			strcat( name, "_nm.tga" );
 			out->normalMap = GL_FindImage( name, it_bump );
 			if( out->normalMap == NULL )
+			{
+				out->has_normalmap = false;
 				out->normalMap = out->image;
-
+			}
+			else
+				out->has_normalmap = true;
 		}
 		else
+		{
+			out->has_normalmap = false;
 			out->normalMap = out->image;
+		}
 
 		strcpy(name, sv_name);
 		if( ( strlen( name ) + 8 ) <= MAX_QPATH )
@@ -744,11 +896,18 @@ void Mod_LoadTexinfo (lump_t *l)
 			strcat( name, "_hm.tga" );
 			out->heightMap = GL_FindImage( name, it_bump );
 			if( out->heightMap == NULL )
+			{
+				out->has_heightmap = false;
 				out->heightMap = out->image;
-
+			}
+			else
+				out->has_heightmap = true;
 		}
 		else
+		{
+			out->has_heightmap = false;
 			out->heightMap = out->image;
+		}
 	}
 
 	// count animation frames
@@ -1259,7 +1418,7 @@ void Mod_LoadBrushModel (model_t *mod, void *buffer)
 	//ODE - clear out any ragdolls;
 	R_ClearAllRagdolls();
 
-	//ODE - create new world(flush out old first?)
+	//ODE - create new world(flush out old first)
 	RGD_DestroyWorldObject();
 	RGD_CreateWorldObject();
 
@@ -1326,6 +1485,7 @@ void Mod_LoadBrushModel (model_t *mod, void *buffer)
 	}
 
 	R_ParseLightEntities();
+	R_FindSunEntity();
 }
 
 //=============================================================================
@@ -1388,6 +1548,13 @@ void R_RegisterBasePlayerModels( void )
 	// int npms = 0; // unused
 	int nskins = 0;
 	char **skinnames;
+	
+	if (is_localhost) {
+	    //then the client is also the server so we have this cvar available
+	    cvar_t *maxclients = Cvar_Get ("maxclients", 0, 0);
+	    if (!maxclients|| maxclients->integer <= 1)
+	        return; //don't bother
+	}
 
 	//precache all player and weapon models(base only, otherwise could take very long loading a map!)
 	for (i = 0; i < PModelsCount; i++)
@@ -1507,6 +1674,7 @@ void R_BeginRegistration (char *model)
 	r_oldviewcluster = -1;		// force markleafs
 
 	r_weather = 0; //default is 0
+	r_nosun = 0;
 
 	// check for fog file, using file system search path
 	path = NULL;
