@@ -16,6 +16,25 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+Notes on shadow rendering:
+
+CRX uses a combination of shadowmapping and stencil volumes for it's shadowing 
+effects.  The shadow maps are used for dynamic shadows only, while the stencil 
+volumes are used for static items and vegetation.  There are a couple of compelling 
+reaons why we do this.  First, the goal is speed.  It is slightly faster to create 
+the volumes than it is to render the mesh to create a shadow caster.  Another 
+consideration is that the stencil volumes cast on any object without the need for 
+a shader to be present.  We are able to create a soft shadow effect by blitting the
+stencil buffer to an offscreen FBO, blurring it in a GLSL shader, then rendering the
+image on a single quad overlay with the correct blending.  
+
+The drawbacks are that we do not have fading penumbras(this could change depending on 
+what the idtech 4 shadow code looks like).  
+
+Dynamic shadows are handled via shadowmaps since dynamic lighting is handled using GLSL.
+This allows us to easily create fading penumbras with dynamic lights.  While it is 
+slightly slower, it allows for an excellent, and accurate effect.
+
 */
 
 #ifdef HAVE_CONFIG_H
@@ -151,6 +170,14 @@ void SHD_MarkIQMShadowTriangles(vec3_t lightOrg)
 	}
 }
 
+/* Notes on this section of code
+   In my tests, it appears that using VBO/IBO for rendering these shadows
+   is actually a tad slower than just building them each time.  There are also
+   some odd problems regarding the bobbing items, as well as the issue with gibs
+   or any other moving object.  The code is left here, commented out, because there
+   are some useful things that could be used in other places of the engine.  However
+   for shadows, it appears to be quite useless.  
+*/
 void SHD_BuildShadowVolume(dmdl_t * hdr, vec3_t light, float projectdistance, qboolean lerp)
 {
 	dtriangle_t *ot, *tris;
@@ -163,6 +190,22 @@ void SHD_BuildShadowVolume(dmdl_t * hdr, vec3_t light, float projectdistance, qb
 	daliasframe_t *frame;
 	dtrivertx_t *verts;
 
+	//check for vbo
+#ifdef SHADOWVBO
+	if(gl_state.vbo && !lerp && !(currententity->flags & RF_BOBBING))
+	{
+		currentmodel->vbo_shadowxyz = R_VCFindCache(VBO_STORE_SHADOWXYZ, currententity);
+		{
+			if (currentmodel->vbo_shadowxyz) 
+			{
+				currentmodel->vbo_shadowindices = R_VCFindCache(VBO_STORE_SHADOWINDICES, currententity);
+				if(currentmodel->vbo_shadowindices)
+					goto skipLoad;
+			}
+		}
+	}
+#endif
+
 	frame = (daliasframe_t *) ((byte *) hdr + hdr->ofs_frames
 							   + currententity->frame * hdr->framesize);
 	verts = frame->verts;
@@ -346,14 +389,46 @@ void SHD_BuildShadowVolume(dmdl_t * hdr, vec3_t light, float projectdistance, qb
 		ShadowIndex[index++] = shadow_vert+0;
 		shadow_vert +=3;
 	}
+#ifdef SHADOWVBO
+	//store vbo
+	if(gl_state.vbo && !lerp)
+	{
+		currentmodel->vbo_shadowxyz = R_VCLoadData(VBO_DYNAMIC, index*sizeof(vec3_t), ShadowArray, VBO_STORE_SHADOWXYZ, currententity);
+		currentmodel->vbo_shadowindices = R_VCLoadData(VBO_DYNAMIC, index*sizeof(unsigned int), ShadowIndex, VBO_STORE_SHADOWINDICES, currententity);
+		//Com_Printf("Loading shadow vbo\n");
+	}
 
-	if ( qglLockArraysEXT != 0 )
-           qglLockArraysEXT( 0, shadow_vert );
+skipLoad:
 
-	qglDrawElements(GL_TRIANGLES, index, GL_UNSIGNED_INT, ShadowIndex);
+	if(gl_state.vbo && !lerp)
+	{		
+        GL_BindVBO(currentmodel->vbo_shadowxyz);
+		qglVertexPointer(3, GL_FLOAT, sizeof(vec3_t), 0);
 
-	if ( qglUnlockArraysEXT != 0 )
-             qglUnlockArraysEXT();
+        GL_BindIBO(currentmodel->vbo_shadowindices);
+	
+		qglDrawElements(GL_TRIANGLES, currentmodel->vbo_shadowxyz->size/sizeof(vec3_t), GL_UNSIGNED_INT, 0);
+
+		GL_BindVBO(NULL);
+		GL_BindIBO(NULL);
+	}
+	else
+#endif
+	{
+		if(shadow_vert > 0)
+		{
+			if(gl_state.vbo)
+				GL_BindVBO(NULL); //make sure that we aren't using an invalid buffer
+
+			if ( qglLockArraysEXT != 0 )
+			   qglLockArraysEXT( 0, shadow_vert );
+
+			qglDrawElements(GL_TRIANGLES, index, GL_UNSIGNED_INT, ShadowIndex);
+
+			if ( qglUnlockArraysEXT != 0 )
+				 qglUnlockArraysEXT();
+		}
+	}
 }
 
 
@@ -491,7 +566,6 @@ void SHD_BuildIQMShadowVolume(vec3_t light, float projectdistance)
 			v0[j] = v0[j] + ((v0[j] - light[j]) * projectdistance);
 			v1[j] = v1[j] + ((v1[j] - light[j]) * projectdistance);
 			v2[j] = v2[j] + ((v2[j] - light[j]) * projectdistance);
-
 		}
 
 		VA_SetElem3(ShadowArray[shadow_vert+0], v0[0], v0[1], v0[2]);
@@ -504,13 +578,19 @@ void SHD_BuildIQMShadowVolume(vec3_t light, float projectdistance)
 		shadow_vert +=3;
 	}
 
-	if ( qglLockArraysEXT != 0 )
-           qglLockArraysEXT( 0, shadow_vert );
+	if(shadow_vert > 0)
+	{
+		if(gl_state.vbo)
+			GL_BindVBO(NULL); //make sure that we aren't using an invalid buffer
 
-	qglDrawElements(GL_TRIANGLES, index, GL_UNSIGNED_INT, ShadowIndex);
+		if ( qglLockArraysEXT != 0 )
+			qglLockArraysEXT( 0, shadow_vert );
 
-	if ( qglUnlockArraysEXT != 0 )
-             qglUnlockArraysEXT();
+		qglDrawElements(GL_TRIANGLES, index, GL_UNSIGNED_INT, ShadowIndex);
+	
+		if ( qglUnlockArraysEXT != 0 )
+			qglUnlockArraysEXT();
+	}
 }
 
 void SHD_RenderVolumes(dmdl_t * paliashdr, vec3_t lightdir, int projdist, qboolean lerp)
