@@ -272,7 +272,6 @@ BSP_RenderBrushPoly
 void BSP_RenderBrushPoly (msurface_t *fa)
 {
 	image_t		*image;
-	qboolean is_dynamic = false;
 	float		scroll;
 
 	c_brush_polys++;
@@ -302,7 +301,7 @@ void BSP_RenderBrushPoly (msurface_t *fa)
 		GL_TexEnv( GL_REPLACE );
 	}
 
-	if(strcmp(fa->texinfo->normalMap->name, fa->texinfo->image->name)) 
+	if(fa->texinfo->has_normalmap) 
 	{
 		//add to normal chain
 		fa->normalchain = r_normalsurfaces;
@@ -450,16 +449,21 @@ void R_DrawAlphaSurfaces (void)
 			s->entity->angles[2] = -s->entity->angles[2];	// stupid quake bug
 		}
 
-		if (s->flags & SURF_DRAWTURB) {
+		if (s->flags & SURF_DRAWTURB) 
+		{
 			//water shaders
-			if(r_shaders->value) {
+			if(r_shaders->value) 
+			{
 				rs_shader = (rscript_t *)s->texinfo->image->script;
-				if(rs_shader) {
+				if(rs_shader) 
+				{
 					stage = rs_shader->stage;
-					if(stage) { //for now, just map a reflection texture
+					if(stage) 
+					{	//for now, just map a reflection texture
 						texnum = stage->texture->texnum; //pass this to renderwaterpolys
 					}
-					if(stage->scale.scaleX != 0 && stage->scale.scaleY !=0) {
+					if(stage->scale.scaleX != 0 && stage->scale.scaleY !=0) 
+					{
 						scaleX = stage->scale.scaleX;
 						scaleY = stage->scale.scaleY;
 					}
@@ -467,24 +471,13 @@ void R_DrawAlphaSurfaces (void)
 			}
 			R_RenderWaterPolys (s, texnum, scaleX, scaleY);
 		}
-		else {
-			if(r_shaders->value && !(s->texinfo->flags & SURF_FLOWING)) {
+		else 
+		{
+			if(r_shaders->value && !(s->texinfo->flags & SURF_FLOWING)) 
+			{
 				rs_shader = (rscript_t *)s->texinfo->image->script;
-				if(rs_shader) {
-
-					qglDepthMask(false);
-					qglShadeModel (GL_SMOOTH);
-					qglEnable(GL_POLYGON_OFFSET_FILL);
-					qglPolygonOffset(-3, -2);
-
+				if(rs_shader) 
 					RS_Surface(s);
-
-					qglDisable(GL_POLYGON_OFFSET_FILL);
-					GLSTATE_DISABLE_BLEND
-					GLSTATE_DISABLE_ALPHATEST
-
-					qglDepthMask(true);
-				}
 				else
 					BSP_DrawPoly (s, s->texinfo->flags);
 			}
@@ -555,7 +548,7 @@ static void BSP_RenderLightmappedPoly( msurface_t *surf )
 	image_t *image = BSP_TextureAnimation( surf->texinfo );
 	unsigned lmtex = surf->lightmaptexturenum;
 	glpoly_t *p = surf->polys;
-		
+
 	c_brush_polys++;
 
 	if (SurfaceIsAlphaBlended(surf))
@@ -577,7 +570,7 @@ static void BSP_RenderLightmappedPoly( msurface_t *surf )
 	qglActiveTextureARB(GL_TEXTURE1);
 	qglBindTexture(GL_TEXTURE_2D, gl_state.lightmap_textures + lmtex );		
 
-	if(strcmp(surf->texinfo->normalMap->name, surf->texinfo->image->name)) 
+	if(surf->texinfo->has_normalmap) 
 	{
 		//add to normal chain
 		surf->normalchain = r_normalsurfaces;
@@ -601,7 +594,7 @@ static void BSP_RenderLightmappedPoly( msurface_t *surf )
 
 		KillFlags |= (KILL_TMU0_POINTER | KILL_TMU1_POINTER);
 				
-		qglDrawArrays (GL_POLYGON, 0, p->numverts);
+		R_DrawVarrays (GL_POLYGON, 0, p->numverts, true);
 
 		qglBindBufferARB(GL_ARRAY_BUFFER_ARB, 0);
 	}
@@ -674,7 +667,7 @@ static void BSP_RenderGLSLLightmappedPoly( msurface_t *surf )
 
 		KillFlags |= (KILL_TMU0_POINTER | KILL_TMU1_POINTER);
 				
-		qglDrawArrays (GL_POLYGON, 0, p->numverts);
+		R_DrawVarrays (GL_POLYGON, 0, p->numverts, true);
 
 		qglBindBufferARB(GL_ARRAY_BUFFER_ARB, 0);
 	}
@@ -707,7 +700,7 @@ static void BSP_RenderGLSLDynamicLightmappedPoly( msurface_t *surf )
 			scroll = -64.0;
 	}
 
-	if(gl_normalmaps->value && strcmp(surf->texinfo->heightMap->name, surf->texinfo->image->name)) 
+	if(gl_normalmaps->value && surf->texinfo->has_heightmap) 
 		glUniform1iARB( g_location_parallax, 1);
 	else
 	{
@@ -757,7 +750,7 @@ static void BSP_RenderGLSLDynamicLightmappedPoly( msurface_t *surf )
 
 		KillFlags |= (KILL_TMU0_POINTER | KILL_TMU1_POINTER);
 				
-		qglDrawArrays (GL_POLYGON, 0, p->numverts);
+		R_DrawVarrays (GL_POLYGON, 0, p->numverts, true);
 
 		qglBindBufferARB(GL_ARRAY_BUFFER_ARB, 0);
 	}
@@ -786,7 +779,22 @@ void BSP_DrawGLSLSurfaces (void)
 	glUniform1iARB( g_location_fog, map_fog);
 	glUniform3fARB( g_location_staticLightPosition, r_worldLightVec[0], r_worldLightVec[1], r_worldLightVec[2]);
 		
-	glUniform1iARB( g_location_shadowmap, 0); //static light shadow handled by stencil volumes
+	if(r_shadowmapcount == 2)
+	{
+		//static vegetation shadow
+		glUniform1iARB( g_location_bspShadowmapTexture2, 6);
+		qglActiveTextureARB(GL_TEXTURE6);
+		qglBindTexture(GL_TEXTURE_2D, r_depthtexture2->texnum);
+
+		glUniform1iARB( g_location_shadowmap, 1);
+		glUniform1iARB( g_Location_statshadow, 1 );
+	}
+	else
+	{
+		glUniform1iARB( g_location_shadowmap, 0);
+		glUniform1iARB( g_Location_statshadow, 0);
+	}
+
 	glUniform1iARB( g_location_dynamic, 0);
 	glUniform1iARB( g_location_parallax, 1);
 	
@@ -1021,14 +1029,14 @@ void BSP_AddToTextureChain(msurface_t *surf)
 		}
 	}
 
-	if(is_dynamic && strcmp(surf->texinfo->normalMap->name, surf->texinfo->image->name)
+	if(is_dynamic && surf->texinfo->has_normalmap
 		&& gl_state.glsl_shaders && gl_glsl_shaders->value) //always glsl for dynamic if it has a normalmap
 	{
 		surf->glsldynamicchain = r_glsl_dynamic_surfaces;
 		r_glsl_dynamic_surfaces = surf;
 	}
-	else if(gl_normalmaps->value && strcmp(surf->texinfo->heightMap->name, surf->texinfo->image->name)
-			&& strcmp(surf->texinfo->normalMap->name, surf->texinfo->image->name)
+	else if(gl_normalmaps->value && surf->texinfo->has_heightmap
+			&& surf->texinfo->has_normalmap
 			&& gl_state.glsl_shaders && gl_glsl_shaders->value) 
 	{
 		surf->glslchain = r_glsl_surfaces;
