@@ -229,7 +229,7 @@ void R_RenderWaterPolys (msurface_t *fa, int texnum, float scaleX, float scaleY)
 		scroll = 0.0f;
 	  
 	if(gl_state.glsl_shaders && gl_glsl_shaders->value
-		&& strcmp(fa->texinfo->normalMap->name, fa->texinfo->image->name)) {
+		&& fa->texinfo->has_normalmap) {
 
 		if (SurfaceIsAlphaBlended(fa))
 			qglEnable( GL_ALPHA_TEST );
@@ -243,29 +243,29 @@ void R_RenderWaterPolys (msurface_t *fa, int texnum, float scaleX, float scaleY)
 		qglActiveTextureARB(GL_TEXTURE0);
 		qglBindTexture (GL_TEXTURE_2D, fa->texinfo->image->texnum);
 		glUniform1iARB( g_location_baseTexture, 0);
-		KillFlags |= KILL_TMU0_POINTER;
 
 		//note - moving this to tmu2 fixed a very odd, obsure bug.  It isn't clear yet why it fixes it, but it does
-		qglActiveTextureARB(GL_TEXTURE2);
+		qglActiveTextureARB(GL_TEXTURE1);
 		qglBindTexture(GL_TEXTURE_2D, fa->texinfo->normalMap->texnum);
-		glUniform1iARB( g_location_normTexture, 2);
-		KillFlags |= KILL_TMU2_POINTER;
+		glUniform1iARB( g_location_normTexture, 1);
 
 		if(fa->texinfo->flags &(SURF_TRANS33|SURF_TRANS66))
 			glUniform1iARB( g_location_trans, 1);
 		else
 			glUniform1iARB( g_location_trans, 0);
 
+		qglActiveTextureARB(GL_TEXTURE2);
+		qglBindTexture(GL_TEXTURE_2D, texnum);
+		glUniform1iARB( g_location_refTexture, 2);
+
 		if(texnum)
 		{
-			qglActiveTextureARB(GL_TEXTURE3);
-			qglBindTexture(GL_TEXTURE_2D, texnum);
-			glUniform1iARB( g_location_refTexture, 3);
-			KillFlags |= KILL_TMU3_POINTER;
 			glUniform1iARB( g_location_reflect, 1);
 		}
 		else
+		{
 			glUniform1iARB( g_location_reflect, 0);
+		}
 			
 		AngleVectors(fa->plane->normal, NULL, tangent, NULL);
 
@@ -290,7 +290,7 @@ void R_RenderWaterPolys (msurface_t *fa, int texnum, float scaleX, float scaleY)
 	}
 	else {
 
-		if (gl_state.fragment_program && strcmp(fa->texinfo->normalMap->name, fa->texinfo->image->name))
+		if (gl_state.fragment_program && fa->texinfo->has_normalmap)
 		{
 			qglEnable(GL_FRAGMENT_PROGRAM_ARB);
 			qglBindProgramARB(GL_FRAGMENT_PROGRAM_ARB, g_water_program_id);
