@@ -190,8 +190,10 @@ void SV_SpawnServer (char *server, char *spawnpoint, server_state_t serverstate,
 	else
 	{
 		Com_sprintf (sv.configstrings[CS_MODELS+1],sizeof(sv.configstrings[CS_MODELS+1]),
-			"maps/%s.bsp", server);
+			"maps/%s", server);
 		sv.models[1] = CM_LoadMap (sv.configstrings[CS_MODELS+1], false, &checksum);
+		Com_sprintf (sv.configstrings[CS_MODELS+1],sizeof(sv.configstrings[CS_MODELS+1]),
+			"%s", map_name);
 	}
 	Com_sprintf (sv.configstrings[CS_MAPCHECKSUM],sizeof(sv.configstrings[CS_MAPCHECKSUM]),
 		"%i", checksum);
@@ -276,8 +278,8 @@ void SV_InitGame (void)
 	}
 
 	//set player move speed according to excessive value
-	sv_excessive = Cvar_Get ("excessive", "0", CVAR_LATCH);
-	sv_playerspeed = Cvar_Get ("playerspeed", "0", CVAR_LATCH);
+	sv_excessive = Cvar_Get ("excessive", "0", CVAR_LATCH|CVAR_GAMEINFO);
+	sv_playerspeed = Cvar_Get ("playerspeed", "0", CVAR_LATCH|CVAR_GAMEINFO);
 	if(sv_excessive->value || sv_playerspeed->value)
 		pm_maxspeed = 450;
 	else
@@ -343,8 +345,10 @@ void SV_Map (qboolean attractloop, char *levelstring, qboolean loadgame)
 
 	sv.attractloop = attractloop;
 
-	if(loadgame || !svs.initialized)
-		SV_InitGame ();	// the game is just starting
+	if ( loadgame || !svs.initialized )
+	{
+		SV_InitGame(); // the game is just starting
+	}
 
 	strcpy (level, levelstring);
 
@@ -372,22 +376,30 @@ void SV_Map (qboolean attractloop, char *levelstring, qboolean loadgame)
 	if (level[0] == '*')
 		strcpy (level, level+1);
 
-	l = strlen(level);
-	if (l > 4 && !strcmp (level+l-4, ".dm2") )
-	{
-		if(!dedicated->value) //this prevents the client from restarting
-			SCR_BeginLoadingPlaque ();			// for local system
-		SV_BroadcastCommand ("changing\n");
-		SV_SpawnServer (level, spawnpoint, ss_demo, attractloop, loadgame);
+	l = strlen( level );
+	if ( l > 4 && !strcmp( level + l - 4, ".dm2" ) )
+	{ // --- Run client-side demo ---
+		if ( !dedicated->value )
+		{ //this prevents the client from restarting
+			SCR_BeginLoadingPlaque(); // for local system
+		}
+		SV_BroadcastCommand( "changing\n" );
+		// make sure attract loop is set. loadgame may be unused.
+		// disable warmup sequence! otherwise, countdown announcements mess up
+		//   configstrings
+		attractloop = true;
+		loadgame    = false;
+		Cvar_ForceSet( "warmuptime", "0" );
+		SV_SpawnServer( level, spawnpoint, ss_demo, attractloop, loadgame );
 	}
 	else
 	{
-		if(!dedicated->value) //this prevents the client from restarting
-			SCR_BeginLoadingPlaque ();			// for local system
-		SV_BroadcastCommand ("changing\n");
-		SV_SendClientMessages ();
-		SV_SpawnServer (level, spawnpoint, ss_game, attractloop, loadgame);
-		Cbuf_CopyToDefer ();
+		if ( !dedicated->value ) //this prevents the client from restarting
+			SCR_BeginLoadingPlaque(); // for local system
+		SV_BroadcastCommand( "changing\n" );
+		SV_SendClientMessages();
+		SV_SpawnServer( level, spawnpoint, ss_game, attractloop, loadgame );
+		Cbuf_CopyToDefer();
 	}
 
 	SV_BroadcastCommand ("reconnect\n");
