@@ -252,7 +252,7 @@ char	*SV_StatusString (void)
 		}
 	}
 	//end bot score info
-	
+
 	return status;
 }
 
@@ -647,9 +647,9 @@ void SVC_DirectConnect (void)
 	// find a client slot
 
 	//get number of bots
-	for (i=0 ; i<maxclients->value ; i++)
+	for (i=botnum=0 ; i<maxclients->value ; i++)
 	{
-		cl = &svs.clients[i]; 
+		cl = &svs.clients[i];
 		botnum = cl->edict->client->ps.botnum;
 		if(botnum > 0)
 			break;
@@ -791,8 +791,14 @@ void SVC_RemoteCommand (void)
 			}
 			strcat (remaining, " ");
 		}
-
-		Cmd_ExecuteString (remaining);
+		if ( strncmp( remaining, "killserver", 10 ) )
+		{ // not too surprising, rcon killserver does bad things
+			Cmd_ExecuteString (remaining);
+		}
+		else
+		{
+			Com_Printf("Cannot do that.\n");
+		}
 	}
 
 	Com_EndRedirect ();
@@ -845,7 +851,9 @@ void SV_ConnectionlessPacket (void)
 		SVC_DirectConnect ();
 	else if (!strcmp(c, "rcon"))
 		SVC_RemoteCommand ();
-	else
+	else if (!strcmp(c, "teamgame")) {
+		Netchan_OutOfBandPrint (NS_SERVER, net_from, "teamgame %f", Cvar_VariableValue ("g_teamgame"));
+	} else
 		Com_Printf ("bad connectionless packet from %s:\n%s\n"
 		, NET_AdrToString (net_from), s);
 }
@@ -936,11 +944,13 @@ void SV_GiveMsec (void)
 SV_ReadPackets
 =================
 */
+extern int sys_msec_as_of_packet_read;
 void SV_ReadPackets (void)
 {
 	int			i;
 	client_t	*cl;
 	int			qport;
+	sys_msec_as_of_packet_read = Sys_Milliseconds ();
 
 	while (NET_GetPacket (NS_SERVER, &net_from, &net_message))
 	{
@@ -1102,8 +1112,13 @@ SV_Frame
 
 ==================
 */
+extern int sys_lasthang;
 void SV_Frame (int msec)
 {
+	int tmp_systime, tmp_hangtime;
+	static int old_systime = 0;
+	if (!old_systime)
+		old_systime = Sys_Milliseconds ();
 	time_before_game = time_after_game = 0;
 
 	// if server is not active, do nothing
@@ -1155,6 +1170,13 @@ void SV_Frame (int msec)
 
 	// clear teleport flags, etc for next frame
 	SV_PrepWorldFrame ();
+	
+	tmp_systime = Sys_Milliseconds ();
+	tmp_hangtime = tmp_systime-old_systime;
+	old_systime = tmp_systime;
+	if (tmp_hangtime > 150) {
+		sys_lasthang = tmp_systime;
+	}
 
 }
 
